'''

The MIT License (MIT)

Copyright (c) 2016 WavyCloud

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

'''

def can_paginate(operation_name=None):
    """
    Check if an operation can be paginated.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').

    """
    pass

def create_bot_version(name=None, checksum=None):
    """
    Creates a new version of the bot based on the $LATEST version. If the $LATEST version of this resource hasn't changed since you created the last version, Amazon Lex doesn't create a new version. It returns the last created version.
    When you create the first version of a bot, Amazon Lex sets the version to 1. Subsequent versions increment by 1. For more information, see  versioning-intro .
    This operation requires permission for the lex:CreateBotVersion action.
    See also: AWS API Documentation
    
    
    :example: response = client.create_bot_version(
        name='string',
        checksum='string'
    )
    
    
    :type name: string
    :param name: [REQUIRED]
            The name of the bot that you want to create a new version of. The name is case sensitive.
            

    :type checksum: string
    :param checksum: Identifies a specific revision of the $LATEST version of the bot. If you specify a checksum and the $LATEST version of the bot has a different checksum, a PreconditionFailedException exception is returned and Amazon Lex doesn't publish a new version. If you don't specify a checksum, Amazon Lex publishes the $LATEST version.

    :rtype: dict
    :return: {
        'name': 'string',
        'description': 'string',
        'intents': [
            {
                'intentName': 'string',
                'intentVersion': 'string'
            },
        ],
        'clarificationPrompt': {
            'messages': [
                {
                    'contentType': 'PlainText'|'SSML',
                    'content': 'string'
                },
            ],
            'maxAttempts': 123,
            'responseCard': 'string'
        },
        'abortStatement': {
            'messages': [
                {
                    'contentType': 'PlainText'|'SSML',
                    'content': 'string'
                },
            ],
            'responseCard': 'string'
        },
        'status': 'BUILDING'|'READY'|'FAILED'|'NOT_BUILT',
        'failureReason': 'string',
        'lastUpdatedDate': datetime(2015, 1, 1),
        'createdDate': datetime(2015, 1, 1),
        'idleSessionTTLInSeconds': 123,
        'voiceId': 'string',
        'checksum': 'string',
        'version': 'string',
        'locale': 'en-US',
        'childDirected': True|False
    }
    
    
    """
    pass

def create_intent_version(name=None, checksum=None):
    """
    Creates a new version of an intent based on the $LATEST version of the intent. If the $LATEST version of this intent hasn't changed since you last updated it, Amazon Lex doesn't create a new version. It returns the last version you created.
    When you create a version of an intent, Amazon Lex sets the version to 1. Subsequent versions increment by 1. For more information, see  versioning-intro .
    This operation requires permissions to perform the lex:CreateIntentVersion action.
    See also: AWS API Documentation
    
    
    :example: response = client.create_intent_version(
        name='string',
        checksum='string'
    )
    
    
    :type name: string
    :param name: [REQUIRED]
            The name of the intent that you want to create a new version of. The name is case sensitive.
            

    :type checksum: string
    :param checksum: Checksum of the $LATEST version of the intent that should be used to create the new version. If you specify a checksum and the $LATEST version of the intent has a different checksum, Amazon Lex returns a PreconditionFailedException exception and doesn't publish a new version. If you don't specify a checksum, Amazon Lex publishes the $LATEST version.

    :rtype: dict
    :return: {
        'name': 'string',
        'description': 'string',
        'slots': [
            {
                'name': 'string',
                'description': 'string',
                'slotConstraint': 'Required'|'Optional',
                'slotType': 'string',
                'slotTypeVersion': 'string',
                'valueElicitationPrompt': {
                    'messages': [
                        {
                            'contentType': 'PlainText'|'SSML',
                            'content': 'string'
                        },
                    ],
                    'maxAttempts': 123,
                    'responseCard': 'string'
                },
                'priority': 123,
                'sampleUtterances': [
                    'string',
                ],
                'responseCard': 'string'
            },
        ],
        'sampleUtterances': [
            'string',
        ],
        'confirmationPrompt': {
            'messages': [
                {
                    'contentType': 'PlainText'|'SSML',
                    'content': 'string'
                },
            ],
            'maxAttempts': 123,
            'responseCard': 'string'
        },
        'rejectionStatement': {
            'messages': [
                {
                    'contentType': 'PlainText'|'SSML',
                    'content': 'string'
                },
            ],
            'responseCard': 'string'
        },
        'followUpPrompt': {
            'prompt': {
                'messages': [
                    {
                        'contentType': 'PlainText'|'SSML',
                        'content': 'string'
                    },
                ],
                'maxAttempts': 123,
                'responseCard': 'string'
            },
            'rejectionStatement': {
                'messages': [
                    {
                        'contentType': 'PlainText'|'SSML',
                        'content': 'string'
                    },
                ],
                'responseCard': 'string'
            }
        },
        'conclusionStatement': {
            'messages': [
                {
                    'contentType': 'PlainText'|'SSML',
                    'content': 'string'
                },
            ],
            'responseCard': 'string'
        },
        'dialogCodeHook': {
            'uri': 'string',
            'messageVersion': 'string'
        },
        'fulfillmentActivity': {
            'type': 'ReturnIntent'|'CodeHook',
            'codeHook': {
                'uri': 'string',
                'messageVersion': 'string'
            }
        },
        'parentIntentSignature': 'string',
        'lastUpdatedDate': datetime(2015, 1, 1),
        'createdDate': datetime(2015, 1, 1),
        'version': 'string',
        'checksum': 'string'
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def create_slot_type_version(name=None, checksum=None):
    """
    Creates a new version of a slot type based on the $LATEST version of the specified slot type. If the $LATEST version of this resource has not changed since the last version that you created, Amazon Lex doesn't create a new version. It returns the last version that you created.
    When you create a version of a slot type, Amazon Lex sets the version to 1. Subsequent versions increment by 1. For more information, see  versioning-intro .
    This operation requires permissions for the lex:CreateSlotTypeVersion action.
    See also: AWS API Documentation
    
    
    :example: response = client.create_slot_type_version(
        name='string',
        checksum='string'
    )
    
    
    :type name: string
    :param name: [REQUIRED]
            The name of the slot type that you want to create a new version for. The name is case sensitive.
            

    :type checksum: string
    :param checksum: Checksum for the $LATEST version of the slot type that you want to publish. If you specify a checksum and the $LATEST version of the slot type has a different checksum, Amazon Lex returns a PreconditionFailedException exception and doesn't publish the new version. If you don't specify a checksum, Amazon Lex publishes the $LATEST version.

    :rtype: dict
    :return: {
        'name': 'string',
        'description': 'string',
        'enumerationValues': [
            {
                'value': 'string'
            },
        ],
        'lastUpdatedDate': datetime(2015, 1, 1),
        'createdDate': datetime(2015, 1, 1),
        'version': 'string',
        'checksum': 'string'
    }
    
    
    :returns: 
    thick
    thin
    stuffed
    
    """
    pass

def delete_bot(name=None):
    """
    Deletes all versions of the bot, including the $LATEST version. To delete a specific version of the bot, use the operation.
    If a bot has an alias, you can't delete it. Instead, the DeleteBot operation returns a ResourceInUseException exception that includes a reference to the alias that refers to the bot. To remove the reference to the bot, delete the alias. If you get the same exception again, delete the referring alias until the DeleteBot operation is successful.
    This operation requires permissions for the lex:DeleteBot action.
    See also: AWS API Documentation
    
    
    :example: response = client.delete_bot(
        name='string'
    )
    
    
    :type name: string
    :param name: [REQUIRED]
            The name of the bot. The name is case sensitive.
            

    """
    pass

def delete_bot_alias(name=None, botName=None):
    """
    Deletes an alias for the specified bot.
    You can't delete an alias that is used in the association between a bot and a messaging channel. If an alias is used in a channel association, the DeleteBot operation returns a ResourceInUseException exception that includes a reference to the channel association that refers to the bot. You can remove the reference to the alias by deleting the channel association. If you get the same exception again, delete the referring association until the DeleteBotAlias operation is successful.
    See also: AWS API Documentation
    
    
    :example: response = client.delete_bot_alias(
        name='string',
        botName='string'
    )
    
    
    :type name: string
    :param name: [REQUIRED]
            The name of the alias to delete. The name is case sensitive.
            

    :type botName: string
    :param botName: [REQUIRED]
            The name of the bot that the alias points to.
            

    """
    pass

def delete_bot_channel_association(name=None, botName=None, botAlias=None):
    """
    Deletes the association between an Amazon Lex bot and a messaging platform.
    This operation requires permission for the lex:DeleteBotChannelAssociation action.
    See also: AWS API Documentation
    
    
    :example: response = client.delete_bot_channel_association(
        name='string',
        botName='string',
        botAlias='string'
    )
    
    
    :type name: string
    :param name: [REQUIRED]
            The name of the association. The name is case sensitive.
            

    :type botName: string
    :param botName: [REQUIRED]
            The name of the Amazon Lex bot.
            

    :type botAlias: string
    :param botAlias: [REQUIRED]
            An alias that points to the specific version of the Amazon Lex bot to which this association is being made.
            

    """
    pass

def delete_bot_version(name=None, version=None):
    """
    Deletes a specific version of a bot. To delete all versions of a bot, use the operation.
    This operation requires permissions for the lex:DeleteBotVersion action.
    See also: AWS API Documentation
    
    
    :example: response = client.delete_bot_version(
        name='string',
        version='string'
    )
    
    
    :type name: string
    :param name: [REQUIRED]
            The name of the bot.
            

    :type version: string
    :param version: [REQUIRED]
            The version of the bot to delete. You cannot delete the $LATEST version of the bot. To delete the $LATEST version, use the operation.
            

    """
    pass

def delete_intent(name=None):
    """
    Deletes all versions of the intent, including the $LATEST version. To delete a specific version of the intent, use the operation.
    You can delete a version of an intent only if it is not referenced. To delete an intent that is referred to in one or more bots (see  how-it-works ), you must remove those references first.
    This operation requires permission for the lex:DeleteIntent action.
    See also: AWS API Documentation
    
    
    :example: response = client.delete_intent(
        name='string'
    )
    
    
    :type name: string
    :param name: [REQUIRED]
            The name of the intent. The name is case sensitive.
            

    """
    pass

def delete_intent_version(name=None, version=None):
    """
    Deletes a specific version of an intent. To delete all versions of a intent, use the operation.
    This operation requires permissions for the lex:DeleteIntentVersion action.
    See also: AWS API Documentation
    
    
    :example: response = client.delete_intent_version(
        name='string',
        version='string'
    )
    
    
    :type name: string
    :param name: [REQUIRED]
            The name of the intent.
            

    :type version: string
    :param version: [REQUIRED]
            The version of the intent to delete. You cannot delete the $LATEST version of the intent. To delete the $LATEST version, use the operation.
            

    """
    pass

def delete_slot_type(name=None):
    """
    Deletes all versions of the slot type, including the $LATEST version. To delete a specific version of the slot type, use the operation.
    You can delete a version of a slot type only if it is not referenced. To delete a slot type that is referred to in one or more intents, you must remove those references first.
    This operation requires permission for the lex:DeleteSlotType action.
    See also: AWS API Documentation
    
    
    :example: response = client.delete_slot_type(
        name='string'
    )
    
    
    :type name: string
    :param name: [REQUIRED]
            The name of the slot type. The name is case sensitive.
            

    """
    pass

def delete_slot_type_version(name=None, version=None):
    """
    Deletes a specific version of a slot type. To delete all versions of a slot type, use the operation.
    This operation requires permissions for the lex:DeleteSlotTypeVersion action.
    See also: AWS API Documentation
    
    
    :example: response = client.delete_slot_type_version(
        name='string',
        version='string'
    )
    
    
    :type name: string
    :param name: [REQUIRED]
            The name of the slot type.
            

    :type version: string
    :param version: [REQUIRED]
            The version of the slot type to delete. You cannot delete the $LATEST version of the slot type. To delete the $LATEST version, use the operation.
            

    """
    pass

def delete_utterances(botName=None, userId=None):
    """
    Deletes stored utterances.
    Amazon Lex stores the utterances that users send to your bot unless the childDirected field in the bot is set to true . Utterances are stored for 15 days for use with the operation, and then stored indefinately for use in improving the ability of your bot to respond to user input.
    Use the DeleteStoredUtterances operation to manually delete stored utterances for a specific user.
    This operation requires permissions for the lex:DeleteUtterances action.
    See also: AWS API Documentation
    
    
    :example: response = client.delete_utterances(
        botName='string',
        userId='string'
    )
    
    
    :type botName: string
    :param botName: [REQUIRED]
            The name of the bot that stored the utterances.
            

    :type userId: string
    :param userId: [REQUIRED]
            The unique identifier for the user that made the utterances. This is the user ID that was sent in the or operation request that contained the utterance.
            

    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    Generate a presigned url given a client, its method, and arguments
    
    :type ClientMethod: string
    :param ClientMethod: The client method to presign for

    :type Params: dict
    :param Params: The parameters normally passed to
            ClientMethod.

    :type ExpiresIn: int
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)

    :type HttpMethod: string
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.

    """
    pass

def get_bot(name=None, versionOrAlias=None):
    """
    Returns metadata information for a specific bot. You must provide the bot name and the bot version or alias.
    The GetBot operation requires permissions for the lex:GetBot action.
    See also: AWS API Documentation
    
    
    :example: response = client.get_bot(
        name='string',
        versionOrAlias='string'
    )
    
    
    :type name: string
    :param name: [REQUIRED]
            The name of the bot. The name is case sensitive.
            

    :type versionOrAlias: string
    :param versionOrAlias: [REQUIRED]
            The version or alias of the bot.
            

    :rtype: dict
    :return: {
        'name': 'string',
        'description': 'string',
        'intents': [
            {
                'intentName': 'string',
                'intentVersion': 'string'
            },
        ],
        'clarificationPrompt': {
            'messages': [
                {
                    'contentType': 'PlainText'|'SSML',
                    'content': 'string'
                },
            ],
            'maxAttempts': 123,
            'responseCard': 'string'
        },
        'abortStatement': {
            'messages': [
                {
                    'contentType': 'PlainText'|'SSML',
                    'content': 'string'
                },
            ],
            'responseCard': 'string'
        },
        'status': 'BUILDING'|'READY'|'FAILED'|'NOT_BUILT',
        'failureReason': 'string',
        'lastUpdatedDate': datetime(2015, 1, 1),
        'createdDate': datetime(2015, 1, 1),
        'idleSessionTTLInSeconds': 123,
        'voiceId': 'string',
        'checksum': 'string',
        'version': 'string',
        'locale': 'en-US',
        'childDirected': True|False
    }
    
    
    """
    pass

def get_bot_alias(name=None, botName=None):
    """
    Returns information about an Amazon Lex bot alias. For more information about aliases, see  versioning-aliases .
    This operation requires permissions for the lex:GetBotAlias action.
    See also: AWS API Documentation
    
    
    :example: response = client.get_bot_alias(
        name='string',
        botName='string'
    )
    
    
    :type name: string
    :param name: [REQUIRED]
            The name of the bot alias. The name is case sensitive.
            

    :type botName: string
    :param botName: [REQUIRED]
            The name of the bot.
            

    :rtype: dict
    :return: {
        'name': 'string',
        'description': 'string',
        'botVersion': 'string',
        'botName': 'string',
        'lastUpdatedDate': datetime(2015, 1, 1),
        'createdDate': datetime(2015, 1, 1),
        'checksum': 'string'
    }
    
    
    """
    pass

def get_bot_aliases(botName=None, nextToken=None, maxResults=None, nameContains=None):
    """
    Returns a list of aliases for a specified Amazon Lex bot.
    This operation requires permissions for the lex:GetBotAliases action.
    See also: AWS API Documentation
    
    
    :example: response = client.get_bot_aliases(
        botName='string',
        nextToken='string',
        maxResults=123,
        nameContains='string'
    )
    
    
    :type botName: string
    :param botName: [REQUIRED]
            The name of the bot.
            

    :type nextToken: string
    :param nextToken: A pagination token for fetching the next page of aliases. If the response to this call is truncated, Amazon Lex returns a pagination token in the response. To fetch the next page of aliases, specify the pagination token in the next request.

    :type maxResults: integer
    :param maxResults: The maximum number of aliases to return in the response. The default is 50. .

    :type nameContains: string
    :param nameContains: Substring to match in bot alias names. An alias will be returned if any part of its name matches the substring. For example, 'xyz' matches both 'xyzabc' and 'abcxyz.'

    :rtype: dict
    :return: {
        'BotAliases': [
            {
                'name': 'string',
                'description': 'string',
                'botVersion': 'string',
                'botName': 'string',
                'lastUpdatedDate': datetime(2015, 1, 1),
                'createdDate': datetime(2015, 1, 1),
                'checksum': 'string'
            },
        ],
        'nextToken': 'string'
    }
    
    
    """
    pass

def get_bot_channel_association(name=None, botName=None, botAlias=None):
    """
    Returns information about the association between an Amazon Lex bot and a messaging platform.
    This operation requires permissions for the lex:GetBotChannelAssociation action.
    See also: AWS API Documentation
    
    
    :example: response = client.get_bot_channel_association(
        name='string',
        botName='string',
        botAlias='string'
    )
    
    
    :type name: string
    :param name: [REQUIRED]
            The name of the association between the bot and the channel. The name is case sensitive.
            

    :type botName: string
    :param botName: [REQUIRED]
            The name of the Amazon Lex bot.
            

    :type botAlias: string
    :param botAlias: [REQUIRED]
            An alias pointing to the specific version of the Amazon Lex bot to which this association is being made.
            

    :rtype: dict
    :return: {
        'name': 'string',
        'description': 'string',
        'botAlias': 'string',
        'botName': 'string',
        'createdDate': datetime(2015, 1, 1),
        'type': 'Facebook'|'Slack'|'Twilio-Sms',
        'botConfiguration': {
            'string': 'string'
        }
    }
    
    
    :returns: 
    (string) --
    (string) --
    
    
    
    """
    pass

def get_bot_channel_associations(botName=None, botAlias=None, nextToken=None, maxResults=None, nameContains=None):
    """
    Returns a list of all of the channels associated with the specified bot.
    The GetBotChannelAssociations operation requires permissions for the lex:GetBotChannelAssociations action.
    See also: AWS API Documentation
    
    
    :example: response = client.get_bot_channel_associations(
        botName='string',
        botAlias='string',
        nextToken='string',
        maxResults=123,
        nameContains='string'
    )
    
    
    :type botName: string
    :param botName: [REQUIRED]
            The name of the Amazon Lex bot in the association.
            

    :type botAlias: string
    :param botAlias: [REQUIRED]
            An alias pointing to the specific version of the Amazon Lex bot to which this association is being made.
            

    :type nextToken: string
    :param nextToken: A pagination token for fetching the next page of associations. If the response to this call is truncated, Amazon Lex returns a pagination token in the response. To fetch the next page of associations, specify the pagination token in the next request.

    :type maxResults: integer
    :param maxResults: The maximum number of associations to return in the response. The default is 50.

    :type nameContains: string
    :param nameContains: Substring to match in channel association names. An association will be returned if any part of its name matches the substring. For example, 'xyz' matches both 'xyzabc' and 'abcxyz.' To return all bot channel associations, use a hyphen ('-') as the nameContains parameter.

    :rtype: dict
    :return: {
        'botChannelAssociations': [
            {
                'name': 'string',
                'description': 'string',
                'botAlias': 'string',
                'botName': 'string',
                'createdDate': datetime(2015, 1, 1),
                'type': 'Facebook'|'Slack'|'Twilio-Sms',
                'botConfiguration': {
                    'string': 'string'
                }
            },
        ],
        'nextToken': 'string'
    }
    
    
    :returns: 
    (string) --
    (string) --
    
    
    
    """
    pass

def get_bot_versions(name=None, nextToken=None, maxResults=None):
    """
    Gets information about all of the versions of a bot.
    The GetBotVersions operation returns a BotMetadata object for each version of a bot. For example, if a bot has three numbered versions, the GetBotVersions operation returns four BotMetadata objects in the response, one for each numbered version and one for the $LATEST version.
    The GetBotVersions operation always returns at least one version, the $LATEST version.
    This operation requires permissions for the lex:GetBotVersions action.
    See also: AWS API Documentation
    
    
    :example: response = client.get_bot_versions(
        name='string',
        nextToken='string',
        maxResults=123
    )
    
    
    :type name: string
    :param name: [REQUIRED]
            The name of the bot for which versions should be returned.
            

    :type nextToken: string
    :param nextToken: A pagination token for fetching the next page of bot versions. If the response to this call is truncated, Amazon Lex returns a pagination token in the response. To fetch the next page of versions, specify the pagination token in the next request.

    :type maxResults: integer
    :param maxResults: The maximum number of bot versions to return in the response. The default is 10.

    :rtype: dict
    :return: {
        'bots': [
            {
                'name': 'string',
                'description': 'string',
                'status': 'BUILDING'|'READY'|'FAILED'|'NOT_BUILT',
                'lastUpdatedDate': datetime(2015, 1, 1),
                'createdDate': datetime(2015, 1, 1),
                'version': 'string'
            },
        ],
        'nextToken': 'string'
    }
    
    
    """
    pass

def get_bots(nextToken=None, maxResults=None, nameContains=None):
    """
    Returns bot information as follows:
    This operation requires permission for the lex:GetBots action.
    See also: AWS API Documentation
    
    
    :example: response = client.get_bots(
        nextToken='string',
        maxResults=123,
        nameContains='string'
    )
    
    
    :type nextToken: string
    :param nextToken: A pagination token that fetches the next page of bots. If the response to this call is truncated, Amazon Lex returns a pagination token in the response. To fetch the next page of bots, specify the pagination token in the next request.

    :type maxResults: integer
    :param maxResults: The maximum number of bots to return in the response that the request will return. The default is 10.

    :type nameContains: string
    :param nameContains: Substring to match in bot names. A bot will be returned if any part of its name matches the substring. For example, 'xyz' matches both 'xyzabc' and 'abcxyz.'

    :rtype: dict
    :return: {
        'bots': [
            {
                'name': 'string',
                'description': 'string',
                'status': 'BUILDING'|'READY'|'FAILED'|'NOT_BUILT',
                'lastUpdatedDate': datetime(2015, 1, 1),
                'createdDate': datetime(2015, 1, 1),
                'version': 'string'
            },
        ],
        'nextToken': 'string'
    }
    
    
    :returns: 
    nextToken (string) -- A pagination token that fetches the next page of bots. If the response to this call is truncated, Amazon Lex returns a pagination token in the response. To fetch the next page of bots, specify the pagination token in the next request.
    maxResults (integer) -- The maximum number of bots to return in the response that the request will return. The default is 10.
    nameContains (string) -- Substring to match in bot names. A bot will be returned if any part of its name matches the substring. For example, "xyz" matches both "xyzabc" and "abcxyz."
    
    """
    pass

def get_builtin_intent(signature=None):
    """
    Returns information about a built-in intent.
    This operation requires permission for the lex:GetBuiltinIntent action.
    See also: AWS API Documentation
    
    
    :example: response = client.get_builtin_intent(
        signature='string'
    )
    
    
    :type signature: string
    :param signature: [REQUIRED]
            The unique identifier for a built-in intent. To find the signature for an intent, see Standard Built-in Intents in the Alexa Skills Kit .
            

    :rtype: dict
    :return: {
        'signature': 'string',
        'supportedLocales': [
            'en-US',
        ],
        'slots': [
            {
                'name': 'string'
            },
        ]
    }
    
    
    """
    pass

def get_builtin_intents(locale=None, signatureContains=None, nextToken=None, maxResults=None):
    """
    Gets a list of built-in intents that meet the specified criteria.
    This operation requires permission for the lex:GetBuiltinIntents action.
    See also: AWS API Documentation
    
    
    :example: response = client.get_builtin_intents(
        locale='en-US',
        signatureContains='string',
        nextToken='string',
        maxResults=123
    )
    
    
    :type locale: string
    :param locale: A list of locales that the intent supports.

    :type signatureContains: string
    :param signatureContains: Substring to match in built-in intent signatures. An intent will be returned if any part of its signature matches the substring. For example, 'xyz' matches both 'xyzabc' and 'abcxyz.' To find the signature for an intent, see Standard Built-in Intents in the Alexa Skills Kit .

    :type nextToken: string
    :param nextToken: A pagination token that fetches the next page of intents. If this API call is truncated, Amazon Lex returns a pagination token in the response. To fetch the next page of intents, use the pagination token in the next request.

    :type maxResults: integer
    :param maxResults: The maximum number of intents to return in the response. The default is 10.

    :rtype: dict
    :return: {
        'intents': [
            {
                'signature': 'string',
                'supportedLocales': [
                    'en-US',
                ]
            },
        ],
        'nextToken': 'string'
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def get_builtin_slot_types(locale=None, signatureContains=None, nextToken=None, maxResults=None):
    """
    Gets a list of built-in slot types that meet the specified criteria.
    For a list of built-in slot types, see Slot Type Reference in the Alexa Skills Kit .
    This operation requires permission for the lex:GetBuiltInSlotTypes action.
    See also: AWS API Documentation
    
    
    :example: response = client.get_builtin_slot_types(
        locale='en-US',
        signatureContains='string',
        nextToken='string',
        maxResults=123
    )
    
    
    :type locale: string
    :param locale: A list of locales that the slot type supports.

    :type signatureContains: string
    :param signatureContains: Substring to match in built-in slot type signatures. A slot type will be returned if any part of its signature matches the substring. For example, 'xyz' matches both 'xyzabc' and 'abcxyz.'

    :type nextToken: string
    :param nextToken: A pagination token that fetches the next page of slot types. If the response to this API call is truncated, Amazon Lex returns a pagination token in the response. To fetch the next page of slot types, specify the pagination token in the next request.

    :type maxResults: integer
    :param maxResults: The maximum number of slot types to return in the response. The default is 10.

    :rtype: dict
    :return: {
        'slotTypes': [
            {
                'signature': 'string',
                'supportedLocales': [
                    'en-US',
                ]
            },
        ],
        'nextToken': 'string'
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def get_intent(name=None, version=None):
    """
    Returns information about an intent. In addition to the intent name, you must specify the intent version.
    This operation requires permissions to perform the lex:GetIntent action.
    See also: AWS API Documentation
    
    
    :example: response = client.get_intent(
        name='string',
        version='string'
    )
    
    
    :type name: string
    :param name: [REQUIRED]
            The name of the intent. The name is case sensitive.
            

    :type version: string
    :param version: [REQUIRED]
            The version of the intent.
            

    :rtype: dict
    :return: {
        'name': 'string',
        'description': 'string',
        'slots': [
            {
                'name': 'string',
                'description': 'string',
                'slotConstraint': 'Required'|'Optional',
                'slotType': 'string',
                'slotTypeVersion': 'string',
                'valueElicitationPrompt': {
                    'messages': [
                        {
                            'contentType': 'PlainText'|'SSML',
                            'content': 'string'
                        },
                    ],
                    'maxAttempts': 123,
                    'responseCard': 'string'
                },
                'priority': 123,
                'sampleUtterances': [
                    'string',
                ],
                'responseCard': 'string'
            },
        ],
        'sampleUtterances': [
            'string',
        ],
        'confirmationPrompt': {
            'messages': [
                {
                    'contentType': 'PlainText'|'SSML',
                    'content': 'string'
                },
            ],
            'maxAttempts': 123,
            'responseCard': 'string'
        },
        'rejectionStatement': {
            'messages': [
                {
                    'contentType': 'PlainText'|'SSML',
                    'content': 'string'
                },
            ],
            'responseCard': 'string'
        },
        'followUpPrompt': {
            'prompt': {
                'messages': [
                    {
                        'contentType': 'PlainText'|'SSML',
                        'content': 'string'
                    },
                ],
                'maxAttempts': 123,
                'responseCard': 'string'
            },
            'rejectionStatement': {
                'messages': [
                    {
                        'contentType': 'PlainText'|'SSML',
                        'content': 'string'
                    },
                ],
                'responseCard': 'string'
            }
        },
        'conclusionStatement': {
            'messages': [
                {
                    'contentType': 'PlainText'|'SSML',
                    'content': 'string'
                },
            ],
            'responseCard': 'string'
        },
        'dialogCodeHook': {
            'uri': 'string',
            'messageVersion': 'string'
        },
        'fulfillmentActivity': {
            'type': 'ReturnIntent'|'CodeHook',
            'codeHook': {
                'uri': 'string',
                'messageVersion': 'string'
            }
        },
        'parentIntentSignature': 'string',
        'lastUpdatedDate': datetime(2015, 1, 1),
        'createdDate': datetime(2015, 1, 1),
        'version': 'string',
        'checksum': 'string'
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def get_intent_versions(name=None, nextToken=None, maxResults=None):
    """
    Gets information about all of the versions of an intent.
    The GetIntentVersions operation returns an IntentMetadata object for each version of an intent. For example, if an intent has three numbered versions, the GetIntentVersions operation returns four IntentMetadata objects in the response, one for each numbered version and one for the $LATEST version.
    The GetIntentVersions operation always returns at least one version, the $LATEST version.
    This operation requires permissions for the lex:GetIntentVersions action.
    See also: AWS API Documentation
    
    
    :example: response = client.get_intent_versions(
        name='string',
        nextToken='string',
        maxResults=123
    )
    
    
    :type name: string
    :param name: [REQUIRED]
            The name of the intent for which versions should be returned.
            

    :type nextToken: string
    :param nextToken: A pagination token for fetching the next page of intent versions. If the response to this call is truncated, Amazon Lex returns a pagination token in the response. To fetch the next page of versions, specify the pagination token in the next request.

    :type maxResults: integer
    :param maxResults: The maximum number of intent versions to return in the response. The default is 10.

    :rtype: dict
    :return: {
        'intents': [
            {
                'name': 'string',
                'description': 'string',
                'lastUpdatedDate': datetime(2015, 1, 1),
                'createdDate': datetime(2015, 1, 1),
                'version': 'string'
            },
        ],
        'nextToken': 'string'
    }
    
    
    """
    pass

def get_intents(nextToken=None, maxResults=None, nameContains=None):
    """
    Returns intent information as follows:
    The operation requires permission for the lex:GetIntents action.
    See also: AWS API Documentation
    
    
    :example: response = client.get_intents(
        nextToken='string',
        maxResults=123,
        nameContains='string'
    )
    
    
    :type nextToken: string
    :param nextToken: A pagination token that fetches the next page of intents. If the response to this API call is truncated, Amazon Lex returns a pagination token in the response. To fetch the next page of intents, specify the pagination token in the next request.

    :type maxResults: integer
    :param maxResults: The maximum number of intents to return in the response. The default is 10.

    :type nameContains: string
    :param nameContains: Substring to match in intent names. An intent will be returned if any part of its name matches the substring. For example, 'xyz' matches both 'xyzabc' and 'abcxyz.'

    :rtype: dict
    :return: {
        'intents': [
            {
                'name': 'string',
                'description': 'string',
                'lastUpdatedDate': datetime(2015, 1, 1),
                'createdDate': datetime(2015, 1, 1),
                'version': 'string'
            },
        ],
        'nextToken': 'string'
    }
    
    
    :returns: 
    nextToken (string) -- A pagination token that fetches the next page of intents. If the response to this API call is truncated, Amazon Lex returns a pagination token in the response. To fetch the next page of intents, specify the pagination token in the next request.
    maxResults (integer) -- The maximum number of intents to return in the response. The default is 10.
    nameContains (string) -- Substring to match in intent names. An intent will be returned if any part of its name matches the substring. For example, "xyz" matches both "xyzabc" and "abcxyz."
    
    """
    pass

def get_paginator(operation_name=None):
    """
    Create a paginator for an operation.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').

    :rtype: L{botocore.paginate.Paginator}
    """
    pass

def get_slot_type(name=None, version=None):
    """
    Returns information about a specific version of a slot type. In addition to specifying the slot type name, you must specify the slot type version.
    This operation requires permissions for the lex:GetSlotType action.
    See also: AWS API Documentation
    
    
    :example: response = client.get_slot_type(
        name='string',
        version='string'
    )
    
    
    :type name: string
    :param name: [REQUIRED]
            The name of the slot type. The name is case sensitive.
            

    :type version: string
    :param version: [REQUIRED]
            The version of the slot type.
            

    :rtype: dict
    :return: {
        'name': 'string',
        'description': 'string',
        'enumerationValues': [
            {
                'value': 'string'
            },
        ],
        'lastUpdatedDate': datetime(2015, 1, 1),
        'createdDate': datetime(2015, 1, 1),
        'version': 'string',
        'checksum': 'string'
    }
    
    
    :returns: 
    thick
    thin
    stuffed
    
    """
    pass

def get_slot_type_versions(name=None, nextToken=None, maxResults=None):
    """
    Gets information about all versions of a slot type.
    The GetSlotTypeVersions operation returns a SlotTypeMetadata object for each version of a slot type. For example, if a slot type has three numbered versions, the GetSlotTypeVersions operation returns four SlotTypeMetadata objects in the response, one for each numbered version and one for the $LATEST version.
    The GetSlotTypeVersions operation always returns at least one version, the $LATEST version.
    This operation requires permissions for the lex:GetSlotTypeVersions action.
    See also: AWS API Documentation
    
    
    :example: response = client.get_slot_type_versions(
        name='string',
        nextToken='string',
        maxResults=123
    )
    
    
    :type name: string
    :param name: [REQUIRED]
            The name of the slot type for which versions should be returned.
            

    :type nextToken: string
    :param nextToken: A pagination token for fetching the next page of slot type versions. If the response to this call is truncated, Amazon Lex returns a pagination token in the response. To fetch the next page of versions, specify the pagination token in the next request.

    :type maxResults: integer
    :param maxResults: The maximum number of slot type versions to return in the response. The default is 10.

    :rtype: dict
    :return: {
        'slotTypes': [
            {
                'name': 'string',
                'description': 'string',
                'lastUpdatedDate': datetime(2015, 1, 1),
                'createdDate': datetime(2015, 1, 1),
                'version': 'string'
            },
        ],
        'nextToken': 'string'
    }
    
    
    """
    pass

def get_slot_types(nextToken=None, maxResults=None, nameContains=None):
    """
    Returns slot type information as follows:
    The operation requires permission for the lex:GetSlotTypes action.
    See also: AWS API Documentation
    
    
    :example: response = client.get_slot_types(
        nextToken='string',
        maxResults=123,
        nameContains='string'
    )
    
    
    :type nextToken: string
    :param nextToken: A pagination token that fetches the next page of slot types. If the response to this API call is truncated, Amazon Lex returns a pagination token in the response. To fetch next page of slot types, specify the pagination token in the next request.

    :type maxResults: integer
    :param maxResults: The maximum number of slot types to return in the response. The default is 10.

    :type nameContains: string
    :param nameContains: Substring to match in slot type names. A slot type will be returned if any part of its name matches the substring. For example, 'xyz' matches both 'xyzabc' and 'abcxyz.'

    :rtype: dict
    :return: {
        'slotTypes': [
            {
                'name': 'string',
                'description': 'string',
                'lastUpdatedDate': datetime(2015, 1, 1),
                'createdDate': datetime(2015, 1, 1),
                'version': 'string'
            },
        ],
        'nextToken': 'string'
    }
    
    
    :returns: 
    nextToken (string) -- A pagination token that fetches the next page of slot types. If the response to this API call is truncated, Amazon Lex returns a pagination token in the response. To fetch next page of slot types, specify the pagination token in the next request.
    maxResults (integer) -- The maximum number of slot types to return in the response. The default is 10.
    nameContains (string) -- Substring to match in slot type names. A slot type will be returned if any part of its name matches the substring. For example, "xyz" matches both "xyzabc" and "abcxyz."
    
    """
    pass

def get_utterances_view(botName=None, botVersions=None, statusType=None):
    """
    Use the GetUtterancesView operation to get information about the utterances that your users have made to your bot. You can use this list to tune the utterances that your bot responds to.
    For example, say that you have created a bot to order flowers. After your users have used your bot for a while, use the GetUtterancesView operation to see the requests that they have made and whether they have been successful. You might find that the utterance "I want flowers" is not being recognized. You could add this utterance to the OrderFlowers intent so that your bot recognizes that utterance.
    After you publish a new version of a bot, you can get information about the old version and the new so that you can compare the performance across the two versions.
    Data is available for the last 15 days. You can request information for up to 5 versions in each request. The response contains information about a maximum of 100 utterances for each version.
    If the bot's childDirected field is set to true , utterances for the bot are not stored and cannot be retrieved with the GetUtterancesView operation. For more information, see .
    This operation requires permissions for the lex:GetUtterancesView action.
    See also: AWS API Documentation
    
    
    :example: response = client.get_utterances_view(
        botName='string',
        botVersions=[
            'string',
        ],
        statusType='Detected'|'Missed'
    )
    
    
    :type botName: string
    :param botName: [REQUIRED]
            The name of the bot for which utterance information should be returned.
            

    :type botVersions: list
    :param botVersions: [REQUIRED]
            An array of bot versions for which utterance information should be returned. The limit is 5 versions per request.
            (string) --
            

    :type statusType: string
    :param statusType: [REQUIRED]
            To return utterances that were recognized and handled, use``Detected`` . To return utterances that were not recognized, use Missed .
            

    :rtype: dict
    :return: {
        'botName': 'string',
        'utterances': [
            {
                'botVersion': 'string',
                'utterances': [
                    {
                        'utteranceString': 'string',
                        'count': 123,
                        'distinctUsers': 123,
                        'firstUtteredDate': datetime(2015, 1, 1),
                        'lastUtteredDate': datetime(2015, 1, 1)
                    },
                ]
            },
        ]
    }
    
    
    """
    pass

def get_waiter():
    """
    
    """
    pass

def put_bot(name=None, description=None, intents=None, clarificationPrompt=None, abortStatement=None, idleSessionTTLInSeconds=None, voiceId=None, checksum=None, processBehavior=None, locale=None, childDirected=None):
    """
    Creates an Amazon Lex conversational bot or replaces an existing bot. When you create or update a bot you only required to specify a name. You can use this to add intents later, or to remove intents from an existing bot. When you create a bot with a name only, the bot is created or updated but Amazon Lex returns the ```` response FAILED . You can build the bot after you add one or more intents. For more information about Amazon Lex bots, see  how-it-works .
    If you specify the name of an existing bot, the fields in the request replace the existing values in the $LATEST version of the bot. Amazon Lex removes any fields that you don't provide values for in the request, except for the idleTTLInSeconds and privacySettings fields, which are set to their default values. If you don't specify values for required fields, Amazon Lex throws an exception.
    This operation requires permissions for the lex:PutBot action. For more information, see  auth-and-access-control .
    See also: AWS API Documentation
    
    
    :example: response = client.put_bot(
        name='string',
        description='string',
        intents=[
            {
                'intentName': 'string',
                'intentVersion': 'string'
            },
        ],
        clarificationPrompt={
            'messages': [
                {
                    'contentType': 'PlainText'|'SSML',
                    'content': 'string'
                },
            ],
            'maxAttempts': 123,
            'responseCard': 'string'
        },
        abortStatement={
            'messages': [
                {
                    'contentType': 'PlainText'|'SSML',
                    'content': 'string'
                },
            ],
            'responseCard': 'string'
        },
        idleSessionTTLInSeconds=123,
        voiceId='string',
        checksum='string',
        processBehavior='SAVE'|'BUILD',
        locale='en-US',
        childDirected=True|False
    )
    
    
    :type name: string
    :param name: [REQUIRED]
            The name of the bot. The name is not case sensitive.
            

    :type description: string
    :param description: A description of the bot.

    :type intents: list
    :param intents: An array of Intent objects. Each intent represents a command that a user can express. For example, a pizza ordering bot might support an OrderPizza intent. For more information, see how-it-works .
            (dict) --Identifies the specific version of an intent.
            intentName (string) -- [REQUIRED]The name of the intent.
            intentVersion (string) -- [REQUIRED]The version of the intent.
            
            

    :type clarificationPrompt: dict
    :param clarificationPrompt: When Amazon Lex doesn't understand the user's intent, it uses one of these messages to get clarification. For example, 'Sorry, I didn't understand. Please repeat.' Amazon Lex repeats the clarification prompt the number of times specified in maxAttempts . If Amazon Lex still can't understand, it sends the message specified in abortStatement .
            messages (list) -- [REQUIRED]An array of objects, each of which provides a message string and its type. You can specify the message string in plain text or in Speech Synthesis Markup Language (SSML).
            (dict) --The message object that provides the message text and its type.
            contentType (string) -- [REQUIRED]The content type of the message string.
            content (string) -- [REQUIRED]The text of the message.
            
            maxAttempts (integer) -- [REQUIRED]The number of times to prompt the user for information.
            responseCard (string) --A response card. Amazon Lex uses this prompt at runtime, in the PostText API response. It substitutes session attributes and slot values for placeholders in the response card. For more information, see ex-resp-card .
            

    :type abortStatement: dict
    :param abortStatement: When Amazon Lex can't understand the user's input in context, it tries to elicit the information a few times. After that, Amazon Lex sends the message defined in abortStatement to the user, and then aborts the conversation. To set the number of retries, use the valueElicitationPrompt field for the slot type.
            For example, in a pizza ordering bot, Amazon Lex might ask a user 'What type of crust would you like?' If the user's response is not one of the expected responses (for example, 'thin crust, 'deep dish,' etc.), Amazon Lex tries to elicit a correct response a few more times.
            For example, in a pizza ordering application, OrderPizza might be one of the intents. This intent might require the CrustType slot. You specify the valueElicitationPrompt field when you create the CrustType slot.
            messages (list) -- [REQUIRED]A collection of message objects.
            (dict) --The message object that provides the message text and its type.
            contentType (string) -- [REQUIRED]The content type of the message string.
            content (string) -- [REQUIRED]The text of the message.
            
            responseCard (string) --At runtime, if the client is using the API, Amazon Lex includes the response card in the response. It substitutes all of the session attributes and slot values for placeholders in the response card.
            

    :type idleSessionTTLInSeconds: integer
    :param idleSessionTTLInSeconds: The maximum time in seconds that Amazon Lex retains the data gathered in a conversation.
            A user interaction session remains active for the amount of time specified. If no conversation occurs during this time, the session expires and Amazon Lex deletes any data provided before the timeout.
            For example, suppose that a user chooses the OrderPizza intent, but gets sidetracked halfway through placing an order. If the user doesn't complete the order within the specified time, Amazon Lex discards the slot information that it gathered, and the user must start over.
            If you don't include the idleSessionTTLInSeconds element in a PutBot operation request, Amazon Lex uses the default value. This is also true if the request replaces an existing bot.
            The default is 300 seconds (5 minutes).
            

    :type voiceId: string
    :param voiceId: The Amazon Polly voice ID that you want Amazon Lex to use for voice interactions with the user. The locale configured for the voice must match the locale of the bot. For more information, see Voice in the Amazon Polly Developer Guide .

    :type checksum: string
    :param checksum: Identifies a specific revision of the $LATEST version.
            When you create a new bot, leave the checksum field blank. If you specify a checksum you get a BadRequestException exception.
            When you want to update a bot, set the checksum field to the checksum of the most recent revision of the $LATEST version. If you don't specify the checksum field, or if the checksum does not match the $LATEST version, you get a PreconditionFailedException exception.
            

    :type processBehavior: string
    :param processBehavior: If you set the processBehavior element to Build , Amazon Lex builds the bot so that it can be run. If you set the element to Save Amazon Lex saves the bot, but doesn't build it.
            If you don't specify this value, the default value is Save .
            

    :type locale: string
    :param locale: [REQUIRED]
            Specifies the target locale for the bot. Any intent used in the bot must be compatible with the locale of the bot.
            The default is en-US .
            

    :type childDirected: boolean
    :param childDirected: [REQUIRED]
            For each Amazon Lex bot created with the Amazon Lex Model Building Service, you must specify whether your use of Amazon Lex is related to a website, program, or other application that is directed or targeted, in whole or in part, to children under age 13 and subject to the Children's Online Privacy Protection Act (COPPA) by specifying true or false in the childDirected field. By specifying true in the childDirected field, you confirm that your use of Amazon Lex is related to a website, program, or other application that is directed or targeted, in whole or in part, to children under age 13 and subject to COPPA. By specifying false in the childDirected field, you confirm that your use of Amazon Lex is not related to a website, program, or other application that is directed or targeted, in whole or in part, to children under age 13 and subject to COPPA. You may not specify a default value for the childDirected field that does not accurately reflect whether your use of Amazon Lex is related to a website, program, or other application that is directed or targeted, in whole or in part, to children under age 13 and subject to COPPA.
            If your use of Amazon Lex relates to a website, program, or other application that is directed in whole or in part, to children under age 13, you must obtain any required verifiable parental consent under COPPA. For information regarding the use of Amazon Lex in connection with websites, programs, or other applications that are directed or targeted, in whole or in part, to children under age 13, see the Amazon Lex FAQ.
            

    :rtype: dict
    :return: {
        'name': 'string',
        'description': 'string',
        'intents': [
            {
                'intentName': 'string',
                'intentVersion': 'string'
            },
        ],
        'clarificationPrompt': {
            'messages': [
                {
                    'contentType': 'PlainText'|'SSML',
                    'content': 'string'
                },
            ],
            'maxAttempts': 123,
            'responseCard': 'string'
        },
        'abortStatement': {
            'messages': [
                {
                    'contentType': 'PlainText'|'SSML',
                    'content': 'string'
                },
            ],
            'responseCard': 'string'
        },
        'status': 'BUILDING'|'READY'|'FAILED'|'NOT_BUILT',
        'failureReason': 'string',
        'lastUpdatedDate': datetime(2015, 1, 1),
        'createdDate': datetime(2015, 1, 1),
        'idleSessionTTLInSeconds': 123,
        'voiceId': 'string',
        'checksum': 'string',
        'version': 'string',
        'locale': 'en-US',
        'childDirected': True|False
    }
    
    
    """
    pass

def put_bot_alias(name=None, description=None, botVersion=None, botName=None, checksum=None):
    """
    Creates an alias for the specified version of the bot or replaces an alias for the specified bot. To change the version of the bot that the alias points to, replace the alias. For more information about aliases, see  versioning-aliases .
    This operation requires permissions for the lex:PutBotAlias action.
    See also: AWS API Documentation
    
    
    :example: response = client.put_bot_alias(
        name='string',
        description='string',
        botVersion='string',
        botName='string',
        checksum='string'
    )
    
    
    :type name: string
    :param name: [REQUIRED]
            The name of the alias. The name is not case sensitive.
            

    :type description: string
    :param description: A description of the alias.

    :type botVersion: string
    :param botVersion: [REQUIRED]
            The version of the bot.
            

    :type botName: string
    :param botName: [REQUIRED]
            The name of the bot.
            

    :type checksum: string
    :param checksum: Identifies a specific revision of the $LATEST version.
            When you create a new bot alias, leave the checksum field blank. If you specify a checksum you get a BadRequestException exception.
            When you want to update a bot alias, set the checksum field to the checksum of the most recent revision of the $LATEST version. If you don't specify the checksum field, or if the checksum does not match the $LATEST version, you get a PreconditionFailedException exception.
            

    :rtype: dict
    :return: {
        'name': 'string',
        'description': 'string',
        'botVersion': 'string',
        'botName': 'string',
        'lastUpdatedDate': datetime(2015, 1, 1),
        'createdDate': datetime(2015, 1, 1),
        'checksum': 'string'
    }
    
    
    """
    pass

def put_intent(name=None, description=None, slots=None, sampleUtterances=None, confirmationPrompt=None, rejectionStatement=None, followUpPrompt=None, conclusionStatement=None, dialogCodeHook=None, fulfillmentActivity=None, parentIntentSignature=None, checksum=None):
    """
    Creates an intent or replaces an existing intent.
    To define the interaction between the user and your bot, you use one or more intents. For a pizza ordering bot, for example, you would create an OrderPizza intent.
    To create an intent or replace an existing intent, you must provide the following:
    You can specify other optional information in the request, such as:
    If you specify an existing intent name to update the intent, Amazon Lex replaces the values in the $LATEST version of the slot type with the values in the request. Amazon Lex removes fields that you don't provide in the request. If you don't specify the required fields, Amazon Lex throws an exception.
    For more information, see  how-it-works .
    This operation requires permissions for the lex:PutIntent action.
    See also: AWS API Documentation
    
    
    :example: response = client.put_intent(
        name='string',
        description='string',
        slots=[
            {
                'name': 'string',
                'description': 'string',
                'slotConstraint': 'Required'|'Optional',
                'slotType': 'string',
                'slotTypeVersion': 'string',
                'valueElicitationPrompt': {
                    'messages': [
                        {
                            'contentType': 'PlainText'|'SSML',
                            'content': 'string'
                        },
                    ],
                    'maxAttempts': 123,
                    'responseCard': 'string'
                },
                'priority': 123,
                'sampleUtterances': [
                    'string',
                ],
                'responseCard': 'string'
            },
        ],
        sampleUtterances=[
            'string',
        ],
        confirmationPrompt={
            'messages': [
                {
                    'contentType': 'PlainText'|'SSML',
                    'content': 'string'
                },
            ],
            'maxAttempts': 123,
            'responseCard': 'string'
        },
        rejectionStatement={
            'messages': [
                {
                    'contentType': 'PlainText'|'SSML',
                    'content': 'string'
                },
            ],
            'responseCard': 'string'
        },
        followUpPrompt={
            'prompt': {
                'messages': [
                    {
                        'contentType': 'PlainText'|'SSML',
                        'content': 'string'
                    },
                ],
                'maxAttempts': 123,
                'responseCard': 'string'
            },
            'rejectionStatement': {
                'messages': [
                    {
                        'contentType': 'PlainText'|'SSML',
                        'content': 'string'
                    },
                ],
                'responseCard': 'string'
            }
        },
        conclusionStatement={
            'messages': [
                {
                    'contentType': 'PlainText'|'SSML',
                    'content': 'string'
                },
            ],
            'responseCard': 'string'
        },
        dialogCodeHook={
            'uri': 'string',
            'messageVersion': 'string'
        },
        fulfillmentActivity={
            'type': 'ReturnIntent'|'CodeHook',
            'codeHook': {
                'uri': 'string',
                'messageVersion': 'string'
            }
        },
        parentIntentSignature='string',
        checksum='string'
    )
    
    
    :type name: string
    :param name: [REQUIRED]
            The name of the intent. The name is not case sensitive.
            The name can't match a built-in intent name, or a built-in intent name with 'AMAZON.' removed. For example, because there is a built-in intent called AMAZON.HelpIntent , you can't create a custom intent called HelpIntent .
            For a list of built-in intents, see Standard Built-in Intents in the Alexa Skills Kit .
            

    :type description: string
    :param description: A description of the intent.

    :type slots: list
    :param slots: An array of intent slots. At runtime, Amazon Lex elicits required slot values from the user using prompts defined in the slots. For more information, see xref linkend='how-it-works'/.
            (dict) --Identifies the version of a specific slot.
            name (string) -- [REQUIRED]The name of the slot.
            description (string) --A description of the slot.
            slotConstraint (string) -- [REQUIRED]Specifies whether the slot is required or optional.
            slotType (string) --The type of the slot, either a custom slot type that you defined or one of the built-in slot types.
            slotTypeVersion (string) --The version of the slot type.
            valueElicitationPrompt (dict) --The prompt that Amazon Lex uses to elicit the slot value from the user.
            messages (list) -- [REQUIRED]An array of objects, each of which provides a message string and its type. You can specify the message string in plain text or in Speech Synthesis Markup Language (SSML).
            (dict) --The message object that provides the message text and its type.
            contentType (string) -- [REQUIRED]The content type of the message string.
            content (string) -- [REQUIRED]The text of the message.
            
            maxAttempts (integer) -- [REQUIRED]The number of times to prompt the user for information.
            responseCard (string) --A response card. Amazon Lex uses this prompt at runtime, in the PostText API response. It substitutes session attributes and slot values for placeholders in the response card. For more information, see ex-resp-card .
            priority (integer) --Directs Lex the order in which to elicit this slot value from the user. For example, if the intent has two slots with priorities 1 and 2, AWS Lex first elicits a value for the slot with priority 1.
            If multiple slots share the same priority, the order in which Lex elicits values is arbitrary.
            sampleUtterances (list) --If you know a specific pattern with which users might respond to an Amazon Lex request for a slot value, you can provide those utterances to improve accuracy. This is optional. In most cases, Amazon Lex is capable of understanding user utterances.
            (string) --
            responseCard (string) --A set of possible responses for the slot type used by text-based clients. A user chooses an option from the response card, instead of using text to reply.
            
            

    :type sampleUtterances: list
    :param sampleUtterances: An array of utterances (strings) that a user might say to signal the intent. For example, 'I want {PizzaSize} pizza', 'Order {Quantity} {PizzaSize} pizzas'.
            In each utterance, a slot name is enclosed in curly braces.
            (string) --
            

    :type confirmationPrompt: dict
    :param confirmationPrompt: Prompts the user to confirm the intent. This question should have a yes or no answer.
            Amazon Lex uses this prompt to ensure that the user acknowledges that the intent is ready for fulfillment. For example, with the OrderPizza intent, you might want to confirm that the order is correct before placing it. For other intents, such as intents that simply respond to user questions, you might not need to ask the user for confirmation before providing the information.
            Note
            You you must provide both the rejectionStatement and the confirmationPrompt , or neither.
            messages (list) -- [REQUIRED]An array of objects, each of which provides a message string and its type. You can specify the message string in plain text or in Speech Synthesis Markup Language (SSML).
            (dict) --The message object that provides the message text and its type.
            contentType (string) -- [REQUIRED]The content type of the message string.
            content (string) -- [REQUIRED]The text of the message.
            
            maxAttempts (integer) -- [REQUIRED]The number of times to prompt the user for information.
            responseCard (string) --A response card. Amazon Lex uses this prompt at runtime, in the PostText API response. It substitutes session attributes and slot values for placeholders in the response card. For more information, see ex-resp-card .
            

    :type rejectionStatement: dict
    :param rejectionStatement: When the user answers 'no' to the question defined in confirmationPrompt , Amazon Lex responds with this statement to acknowledge that the intent was canceled.
            Note
            You must provide both the rejectionStatement and the confirmationPrompt , or neither.
            messages (list) -- [REQUIRED]A collection of message objects.
            (dict) --The message object that provides the message text and its type.
            contentType (string) -- [REQUIRED]The content type of the message string.
            content (string) -- [REQUIRED]The text of the message.
            
            responseCard (string) --At runtime, if the client is using the API, Amazon Lex includes the response card in the response. It substitutes all of the session attributes and slot values for placeholders in the response card.
            

    :type followUpPrompt: dict
    :param followUpPrompt: A user prompt for additional activity after an intent is fulfilled. For example, after the OrderPizza intent is fulfilled (your Lambda function placed an order with a pizzeria), you might prompt the user to find if they want to order a drink (assuming that you have defined an OrderDrink intent in your bot).
            Note
            The followUpPrompt and conclusionStatement are mutually exclusive. You can specify only one. For example, your bot may not solicit both the following:
            Follow up prompt - '$session.FirstName , your pizza order has been placed. Would you like to order a drink or a dessert?'
            Conclusion statement - '$session.FirstName , your pizza order has been placed.'
            prompt (dict) -- [REQUIRED]Obtains information from the user.
            messages (list) -- [REQUIRED]An array of objects, each of which provides a message string and its type. You can specify the message string in plain text or in Speech Synthesis Markup Language (SSML).
            (dict) --The message object that provides the message text and its type.
            contentType (string) -- [REQUIRED]The content type of the message string.
            content (string) -- [REQUIRED]The text of the message.
            
            maxAttempts (integer) -- [REQUIRED]The number of times to prompt the user for information.
            responseCard (string) --A response card. Amazon Lex uses this prompt at runtime, in the PostText API response. It substitutes session attributes and slot values for placeholders in the response card. For more information, see ex-resp-card .
            rejectionStatement (dict) -- [REQUIRED]If the user answers 'no' to the question defined in confirmationPrompt , Amazon Lex responds with this statement to acknowledge that the intent was canceled.
            messages (list) -- [REQUIRED]A collection of message objects.
            (dict) --The message object that provides the message text and its type.
            contentType (string) -- [REQUIRED]The content type of the message string.
            content (string) -- [REQUIRED]The text of the message.
            
            responseCard (string) --At runtime, if the client is using the API, Amazon Lex includes the response card in the response. It substitutes all of the session attributes and slot values for placeholders in the response card.
            
            

    :type conclusionStatement: dict
    :param conclusionStatement: The statement that you want Amazon Lex to convey to the user after the intent is successfully fulfilled by the Lambda function.
            This element is relevant only if you provide a Lambda function in the fulfillmentActivity . If you return the intent to the client application, you can't specify this element.
            Note
            The followUpPrompt and conclusionStatement are mutually exclusive. You can specify only one.
            messages (list) -- [REQUIRED]A collection of message objects.
            (dict) --The message object that provides the message text and its type.
            contentType (string) -- [REQUIRED]The content type of the message string.
            content (string) -- [REQUIRED]The text of the message.
            
            responseCard (string) --At runtime, if the client is using the API, Amazon Lex includes the response card in the response. It substitutes all of the session attributes and slot values for placeholders in the response card.
            

    :type dialogCodeHook: dict
    :param dialogCodeHook: Specifies a Lambda function to invoke for each user input. You can invoke this Lambda function to personalize user interaction.
            For example, suppose your bot determines that the user is John. Your Lambda function might retrieve John's information from a backend database and prepopulate some of the values. For example, if you find that John is gluten intolerant, you might set the corresponding intent slot, GlutenIntolerant , to true. You might find John's phone number and set the corresponding session attribute.
            uri (string) -- [REQUIRED]The Amazon Resource Name (ARN) of the Lambda function.
            messageVersion (string) -- [REQUIRED]The version of the request-response that you want Amazon Lex to use to invoke your Lambda function. For more information, see using-lambda .
            

    :type fulfillmentActivity: dict
    :param fulfillmentActivity: Describes how the intent is fulfilled. For example, after a user provides all of the information for a pizza order, fulfillmentActivity defines how the bot places an order with a local pizza store.
            You might configure Amazon Lex to return all of the intent information to the client application, or direct it to invoke a Lambda function that can process the intent (for example, place an order with a pizzeria).
            type (string) -- [REQUIRED]How the intent should be fulfilled, either by running a Lambda function or by returning the slot data to the client application.
            codeHook (dict) --A description of the Lambda function that is run to fulfill the intent.
            uri (string) -- [REQUIRED]The Amazon Resource Name (ARN) of the Lambda function.
            messageVersion (string) -- [REQUIRED]The version of the request-response that you want Amazon Lex to use to invoke your Lambda function. For more information, see using-lambda .
            
            

    :type parentIntentSignature: string
    :param parentIntentSignature: A unique identifier for the built-in intent to base this intent on. To find the signature for an intent, see Standard Built-in Intents in the Alexa Skills Kit .

    :type checksum: string
    :param checksum: Identifies a specific revision of the $LATEST version.
            When you create a new intent, leave the checksum field blank. If you specify a checksum you get a BadRequestException exception.
            When you want to update a intent, set the checksum field to the checksum of the most recent revision of the $LATEST version. If you don't specify the checksum field, or if the checksum does not match the $LATEST version, you get a PreconditionFailedException exception.
            

    :rtype: dict
    :return: {
        'name': 'string',
        'description': 'string',
        'slots': [
            {
                'name': 'string',
                'description': 'string',
                'slotConstraint': 'Required'|'Optional',
                'slotType': 'string',
                'slotTypeVersion': 'string',
                'valueElicitationPrompt': {
                    'messages': [
                        {
                            'contentType': 'PlainText'|'SSML',
                            'content': 'string'
                        },
                    ],
                    'maxAttempts': 123,
                    'responseCard': 'string'
                },
                'priority': 123,
                'sampleUtterances': [
                    'string',
                ],
                'responseCard': 'string'
            },
        ],
        'sampleUtterances': [
            'string',
        ],
        'confirmationPrompt': {
            'messages': [
                {
                    'contentType': 'PlainText'|'SSML',
                    'content': 'string'
                },
            ],
            'maxAttempts': 123,
            'responseCard': 'string'
        },
        'rejectionStatement': {
            'messages': [
                {
                    'contentType': 'PlainText'|'SSML',
                    'content': 'string'
                },
            ],
            'responseCard': 'string'
        },
        'followUpPrompt': {
            'prompt': {
                'messages': [
                    {
                        'contentType': 'PlainText'|'SSML',
                        'content': 'string'
                    },
                ],
                'maxAttempts': 123,
                'responseCard': 'string'
            },
            'rejectionStatement': {
                'messages': [
                    {
                        'contentType': 'PlainText'|'SSML',
                        'content': 'string'
                    },
                ],
                'responseCard': 'string'
            }
        },
        'conclusionStatement': {
            'messages': [
                {
                    'contentType': 'PlainText'|'SSML',
                    'content': 'string'
                },
            ],
            'responseCard': 'string'
        },
        'dialogCodeHook': {
            'uri': 'string',
            'messageVersion': 'string'
        },
        'fulfillmentActivity': {
            'type': 'ReturnIntent'|'CodeHook',
            'codeHook': {
                'uri': 'string',
                'messageVersion': 'string'
            }
        },
        'parentIntentSignature': 'string',
        'lastUpdatedDate': datetime(2015, 1, 1),
        'createdDate': datetime(2015, 1, 1),
        'version': 'string',
        'checksum': 'string'
    }
    
    
    :returns: 
    A confirmation prompt to ask the user to confirm an intent. For example, "Shall I order your pizza?"
    A conclusion statement to send to the user after the intent has been fulfilled. For example, "I placed your pizza order."
    A follow-up prompt that asks the user for additional activity. For example, asking "Do you want to order a drink with your pizza?"
    
    """
    pass

def put_slot_type(name=None, description=None, enumerationValues=None, checksum=None):
    """
    Creates a custom slot type or replaces an existing custom slot type.
    To create a custom slot type, specify a name for the slot type and a set of enumeration values, which are the values that a slot of this type can assume. For more information, see  how-it-works .
    If you specify the name of an existing slot type, the fields in the request replace the existing values in the $LATEST version of the slot type. Amazon Lex removes the fields that you don't provide in the request. If you don't specify required fields, Amazon Lex throws an exception.
    This operation requires permissions for the lex:PutSlotType action.
    See also: AWS API Documentation
    
    
    :example: response = client.put_slot_type(
        name='string',
        description='string',
        enumerationValues=[
            {
                'value': 'string'
            },
        ],
        checksum='string'
    )
    
    
    :type name: string
    :param name: [REQUIRED]
            The name of the slot type. The name is not case sensitive.
            The name can't match a built-in slot type name, or a built-in slot type name with 'AMAZON.' removed. For example, because there is a built-in slot type called AMAZON.DATE , you can't create a custom slot type called DATE .
            For a list of built-in slot types, see Slot Type Reference in the Alexa Skills Kit .
            

    :type description: string
    :param description: A description of the slot type.

    :type enumerationValues: list
    :param enumerationValues: A list of EnumerationValue objects that defines the values that the slot type can take.
            (dict) --Each slot type can have a set of values. Each enumeration value represents a value the slot type can take.
            For example, a pizza ordering bot could have a slot type that specifies the type of crust that the pizza should have. The slot type could include the values
            thick
            thin
            stuffed
            value (string) -- [REQUIRED]The value of the slot type.
            
            

    :type checksum: string
    :param checksum: Identifies a specific revision of the $LATEST version.
            When you create a new slot type, leave the checksum field blank. If you specify a checksum you get a BadRequestException exception.
            When you want to update a slot type, set the checksum field to the checksum of the most recent revision of the $LATEST version. If you don't specify the checksum field, or if the checksum does not match the $LATEST version, you get a PreconditionFailedException exception.
            

    :rtype: dict
    :return: {
        'name': 'string',
        'description': 'string',
        'enumerationValues': [
            {
                'value': 'string'
            },
        ],
        'lastUpdatedDate': datetime(2015, 1, 1),
        'createdDate': datetime(2015, 1, 1),
        'version': 'string',
        'checksum': 'string'
    }
    
    
    :returns: 
    thick
    thin
    stuffed
    
    """
    pass




'''

The MIT License (MIT)

Copyright (c) 2016 WavyCloud

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

'''

def can_paginate(operation_name=None):
    """
    Check if an operation can be paginated.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').

    """
    pass

def describe_affected_entities(filter=None, locale=None, nextToken=None, maxResults=None):
    """
    Returns a list of entities that have been affected by the specified events, based on the specified filter criteria. Entities can refer to individual customer resources, groups of customer resources, or any other construct, depending on the AWS service. Events that have impact beyond that of the affected entities, or where the extent of impact is unknown, include at least one entity indicating this.
    At least one event ARN is required. Results are sorted by the lastUpdatedTime of the entity, starting with the most recent.
    See also: AWS API Documentation
    
    
    :example: response = client.describe_affected_entities(
        filter={
            'eventArns': [
                'string',
            ],
            'entityArns': [
                'string',
            ],
            'entityValues': [
                'string',
            ],
            'lastUpdatedTimes': [
                {
                    'from': datetime(2015, 1, 1),
                    'to': datetime(2015, 1, 1)
                },
            ],
            'tags': [
                {
                    'string': 'string'
                },
            ],
            'statusCodes': [
                'IMPAIRED'|'UNIMPAIRED'|'UNKNOWN',
            ]
        },
        locale='string',
        nextToken='string',
        maxResults=123
    )
    
    
    :type filter: dict
    :param filter: [REQUIRED]
            Values to narrow the results returned. At least one event ARN is required.
            eventArns (list) -- [REQUIRED]A list of event ARNs (unique identifiers). For example: 'arn:aws:health:us-east-1::event/AWS_EC2_MAINTENANCE_5331', 'arn:aws:health:us-west-1::event/AWS_EBS_LOST_VOLUME_xyz'
            (string) --
            entityArns (list) --A list of entity ARNs (unique identifiers).
            (string) --
            entityValues (list) --A list of IDs for affected entities.
            (string) --
            lastUpdatedTimes (list) --A list of the most recent dates and times that the entity was updated.
            (dict) --A range of dates and times that is used by the EventFilter and EntityFilter objects. If from is set and to is set: match items where the timestamp (startTime , endTime , or lastUpdatedTime ) is between from and to inclusive. If from is set and to is not set: match items where the timestamp value is equal to or after from . If from is not set and to is set: match items where the timestamp value is equal to or before to .
            from (datetime) --The starting date and time of a time range.
            to (datetime) --The ending date and time of a time range.
            
            tags (list) --A map of entity tags attached to the affected entity.
            (dict) --
            (string) --
            (string) --
            
            statusCodes (list) --A list of entity status codes (IMPAIRED , UNIMPAIRED , or UNKNOWN ).
            (string) --
            

    :type locale: string
    :param locale: The locale (language) to return information in. English (en) is the default and the only supported value at this time.

    :type nextToken: string
    :param nextToken: If the results of a search are large, only a portion of the results are returned, and a nextToken pagination token is returned in the response. To retrieve the next batch of results, reissue the search request and include the returned token. When all results have been returned, the response does not contain a pagination token value.

    :type maxResults: integer
    :param maxResults: The maximum number of items to return in one batch, between 10 and 100, inclusive.

    :rtype: dict
    :return: {
        'entities': [
            {
                'entityArn': 'string',
                'eventArn': 'string',
                'entityValue': 'string',
                'awsAccountId': 'string',
                'lastUpdatedTime': datetime(2015, 1, 1),
                'statusCode': 'IMPAIRED'|'UNIMPAIRED'|'UNKNOWN',
                'tags': {
                    'string': 'string'
                }
            },
        ],
        'nextToken': 'string'
    }
    
    
    :returns: 
    (string) --
    (string) --
    
    
    
    """
    pass

def describe_entity_aggregates(eventArns=None):
    """
    Returns the number of entities that are affected by each of the specified events. If no events are specified, the counts of all affected entities are returned.
    See also: AWS API Documentation
    
    
    :example: response = client.describe_entity_aggregates(
        eventArns=[
            'string',
        ]
    )
    
    
    :type eventArns: list
    :param eventArns: A list of event ARNs (unique identifiers). For example: 'arn:aws:health:us-east-1::event/AWS_EC2_MAINTENANCE_5331', 'arn:aws:health:us-west-1::event/AWS_EBS_LOST_VOLUME_xyz'
            (string) --
            

    :rtype: dict
    :return: {
        'entityAggregates': [
            {
                'eventArn': 'string',
                'count': 123
            },
        ]
    }
    
    
    """
    pass

def describe_event_aggregates(filter=None, aggregateField=None, maxResults=None, nextToken=None):
    """
    Returns the number of events of each event type (issue, scheduled change, and account notification). If no filter is specified, the counts of all events in each category are returned.
    See also: AWS API Documentation
    
    
    :example: response = client.describe_event_aggregates(
        filter={
            'eventArns': [
                'string',
            ],
            'eventTypeCodes': [
                'string',
            ],
            'services': [
                'string',
            ],
            'regions': [
                'string',
            ],
            'availabilityZones': [
                'string',
            ],
            'startTimes': [
                {
                    'from': datetime(2015, 1, 1),
                    'to': datetime(2015, 1, 1)
                },
            ],
            'endTimes': [
                {
                    'from': datetime(2015, 1, 1),
                    'to': datetime(2015, 1, 1)
                },
            ],
            'lastUpdatedTimes': [
                {
                    'from': datetime(2015, 1, 1),
                    'to': datetime(2015, 1, 1)
                },
            ],
            'entityArns': [
                'string',
            ],
            'entityValues': [
                'string',
            ],
            'eventTypeCategories': [
                'issue'|'accountNotification'|'scheduledChange',
            ],
            'tags': [
                {
                    'string': 'string'
                },
            ],
            'eventStatusCodes': [
                'open'|'closed'|'upcoming',
            ]
        },
        aggregateField='eventTypeCategory',
        maxResults=123,
        nextToken='string'
    )
    
    
    :type filter: dict
    :param filter: Values to narrow the results returned.
            eventArns (list) --A list of event ARNs (unique identifiers). For example: 'arn:aws:health:us-east-1::event/AWS_EC2_MAINTENANCE_5331', 'arn:aws:health:us-west-1::event/AWS_EBS_LOST_VOLUME_xyz'
            (string) --
            eventTypeCodes (list) --A list of unique identifiers for event types. For example, 'AWS_EC2_SYSTEM_MAINTENANCE_EVENT','AWS_RDS_MAINTENANCE_SCHEDULED'
            (string) --
            services (list) --The AWS services associated with the event. For example, EC2 , RDS .
            (string) --
            regions (list) --A list of AWS regions.
            (string) --
            availabilityZones (list) --A list of AWS availability zones.
            (string) --
            startTimes (list) --A list of dates and times that the event began.
            (dict) --A range of dates and times that is used by the EventFilter and EntityFilter objects. If from is set and to is set: match items where the timestamp (startTime , endTime , or lastUpdatedTime ) is between from and to inclusive. If from is set and to is not set: match items where the timestamp value is equal to or after from . If from is not set and to is set: match items where the timestamp value is equal to or before to .
            from (datetime) --The starting date and time of a time range.
            to (datetime) --The ending date and time of a time range.
            
            endTimes (list) --A list of dates and times that the event ended.
            (dict) --A range of dates and times that is used by the EventFilter and EntityFilter objects. If from is set and to is set: match items where the timestamp (startTime , endTime , or lastUpdatedTime ) is between from and to inclusive. If from is set and to is not set: match items where the timestamp value is equal to or after from . If from is not set and to is set: match items where the timestamp value is equal to or before to .
            from (datetime) --The starting date and time of a time range.
            to (datetime) --The ending date and time of a time range.
            
            lastUpdatedTimes (list) --A list of dates and times that the event was last updated.
            (dict) --A range of dates and times that is used by the EventFilter and EntityFilter objects. If from is set and to is set: match items where the timestamp (startTime , endTime , or lastUpdatedTime ) is between from and to inclusive. If from is set and to is not set: match items where the timestamp value is equal to or after from . If from is not set and to is set: match items where the timestamp value is equal to or before to .
            from (datetime) --The starting date and time of a time range.
            to (datetime) --The ending date and time of a time range.
            
            entityArns (list) --A list of entity ARNs (unique identifiers).
            (string) --
            entityValues (list) --A list of entity identifiers, such as EC2 instance IDs (i-34ab692e ) or EBS volumes (vol-426ab23e ).
            (string) --
            eventTypeCategories (list) --A list of event type category codes (issue , scheduledChange , or accountNotification ).
            (string) --
            tags (list) --A map of entity tags attached to the affected entity.
            (dict) --
            (string) --
            (string) --
            
            eventStatusCodes (list) --A list of event status codes.
            (string) --
            

    :type aggregateField: string
    :param aggregateField: [REQUIRED]
            The only currently supported value is eventTypeCategory .
            

    :type maxResults: integer
    :param maxResults: The maximum number of items to return in one batch, between 10 and 100, inclusive.

    :type nextToken: string
    :param nextToken: If the results of a search are large, only a portion of the results are returned, and a nextToken pagination token is returned in the response. To retrieve the next batch of results, reissue the search request and include the returned token. When all results have been returned, the response does not contain a pagination token value.

    :rtype: dict
    :return: {
        'eventAggregates': [
            {
                'aggregateValue': 'string',
                'count': 123
            },
        ],
        'nextToken': 'string'
    }
    
    
    """
    pass

def describe_event_details(eventArns=None, locale=None):
    """
    Returns detailed information about one or more specified events. Information includes standard event data (region, service, etc., as returned by  DescribeEvents ), a detailed event description, and possible additional metadata that depends upon the nature of the event. Affected entities are not included; to retrieve those, use the  DescribeAffectedEntities operation.
    If a specified event cannot be retrieved, an error message is returned for that event.
    See also: AWS API Documentation
    
    
    :example: response = client.describe_event_details(
        eventArns=[
            'string',
        ],
        locale='string'
    )
    
    
    :type eventArns: list
    :param eventArns: [REQUIRED]
            A list of event ARNs (unique identifiers). For example: 'arn:aws:health:us-east-1::event/AWS_EC2_MAINTENANCE_5331', 'arn:aws:health:us-west-1::event/AWS_EBS_LOST_VOLUME_xyz'
            (string) --
            

    :type locale: string
    :param locale: The locale (language) to return information in. English (en) is the default and the only supported value at this time.

    :rtype: dict
    :return: {
        'successfulSet': [
            {
                'event': {
                    'arn': 'string',
                    'service': 'string',
                    'eventTypeCode': 'string',
                    'eventTypeCategory': 'issue'|'accountNotification'|'scheduledChange',
                    'region': 'string',
                    'availabilityZone': 'string',
                    'startTime': datetime(2015, 1, 1),
                    'endTime': datetime(2015, 1, 1),
                    'lastUpdatedTime': datetime(2015, 1, 1),
                    'statusCode': 'open'|'closed'|'upcoming'
                },
                'eventDescription': {
                    'latestDescription': 'string'
                },
                'eventMetadata': {
                    'string': 'string'
                }
            },
        ],
        'failedSet': [
            {
                'eventArn': 'string',
                'errorName': 'string',
                'errorMessage': 'string'
            },
        ]
    }
    
    
    :returns: 
    (string) --
    (string) --
    
    
    
    """
    pass

def describe_event_types(filter=None, locale=None, nextToken=None, maxResults=None):
    """
    Returns the event types that meet the specified filter criteria. If no filter criteria are specified, all event types are returned, in no particular order.
    See also: AWS API Documentation
    
    
    :example: response = client.describe_event_types(
        filter={
            'eventTypeCodes': [
                'string',
            ],
            'services': [
                'string',
            ],
            'eventTypeCategories': [
                'issue'|'accountNotification'|'scheduledChange',
            ]
        },
        locale='string',
        nextToken='string',
        maxResults=123
    )
    
    
    :type filter: dict
    :param filter: Values to narrow the results returned.
            eventTypeCodes (list) --A list of event type codes.
            (string) --
            services (list) --The AWS services associated with the event. For example, EC2 , RDS .
            (string) --
            eventTypeCategories (list) --A list of event type category codes (issue , scheduledChange , or accountNotification ).
            (string) --
            

    :type locale: string
    :param locale: The locale (language) to return information in. English (en) is the default and the only supported value at this time.

    :type nextToken: string
    :param nextToken: If the results of a search are large, only a portion of the results are returned, and a nextToken pagination token is returned in the response. To retrieve the next batch of results, reissue the search request and include the returned token. When all results have been returned, the response does not contain a pagination token value.

    :type maxResults: integer
    :param maxResults: The maximum number of items to return in one batch, between 10 and 100, inclusive.

    :rtype: dict
    :return: {
        'eventTypes': [
            {
                'service': 'string',
                'code': 'string',
                'category': 'issue'|'accountNotification'|'scheduledChange'
            },
        ],
        'nextToken': 'string'
    }
    
    
    """
    pass

def describe_events(filter=None, nextToken=None, maxResults=None, locale=None):
    """
    Returns information about events that meet the specified filter criteria. Events are returned in a summary form and do not include the detailed description, any additional metadata that depends on the event type, or any affected resources. To retrieve that information, use the  DescribeEventDetails and  DescribeAffectedEntities operations.
    If no filter criteria are specified, all events are returned. Results are sorted by lastModifiedTime , starting with the most recent.
    See also: AWS API Documentation
    
    
    :example: response = client.describe_events(
        filter={
            'eventArns': [
                'string',
            ],
            'eventTypeCodes': [
                'string',
            ],
            'services': [
                'string',
            ],
            'regions': [
                'string',
            ],
            'availabilityZones': [
                'string',
            ],
            'startTimes': [
                {
                    'from': datetime(2015, 1, 1),
                    'to': datetime(2015, 1, 1)
                },
            ],
            'endTimes': [
                {
                    'from': datetime(2015, 1, 1),
                    'to': datetime(2015, 1, 1)
                },
            ],
            'lastUpdatedTimes': [
                {
                    'from': datetime(2015, 1, 1),
                    'to': datetime(2015, 1, 1)
                },
            ],
            'entityArns': [
                'string',
            ],
            'entityValues': [
                'string',
            ],
            'eventTypeCategories': [
                'issue'|'accountNotification'|'scheduledChange',
            ],
            'tags': [
                {
                    'string': 'string'
                },
            ],
            'eventStatusCodes': [
                'open'|'closed'|'upcoming',
            ]
        },
        nextToken='string',
        maxResults=123,
        locale='string'
    )
    
    
    :type filter: dict
    :param filter: Values to narrow the results returned.
            eventArns (list) --A list of event ARNs (unique identifiers). For example: 'arn:aws:health:us-east-1::event/AWS_EC2_MAINTENANCE_5331', 'arn:aws:health:us-west-1::event/AWS_EBS_LOST_VOLUME_xyz'
            (string) --
            eventTypeCodes (list) --A list of unique identifiers for event types. For example, 'AWS_EC2_SYSTEM_MAINTENANCE_EVENT','AWS_RDS_MAINTENANCE_SCHEDULED'
            (string) --
            services (list) --The AWS services associated with the event. For example, EC2 , RDS .
            (string) --
            regions (list) --A list of AWS regions.
            (string) --
            availabilityZones (list) --A list of AWS availability zones.
            (string) --
            startTimes (list) --A list of dates and times that the event began.
            (dict) --A range of dates and times that is used by the EventFilter and EntityFilter objects. If from is set and to is set: match items where the timestamp (startTime , endTime , or lastUpdatedTime ) is between from and to inclusive. If from is set and to is not set: match items where the timestamp value is equal to or after from . If from is not set and to is set: match items where the timestamp value is equal to or before to .
            from (datetime) --The starting date and time of a time range.
            to (datetime) --The ending date and time of a time range.
            
            endTimes (list) --A list of dates and times that the event ended.
            (dict) --A range of dates and times that is used by the EventFilter and EntityFilter objects. If from is set and to is set: match items where the timestamp (startTime , endTime , or lastUpdatedTime ) is between from and to inclusive. If from is set and to is not set: match items where the timestamp value is equal to or after from . If from is not set and to is set: match items where the timestamp value is equal to or before to .
            from (datetime) --The starting date and time of a time range.
            to (datetime) --The ending date and time of a time range.
            
            lastUpdatedTimes (list) --A list of dates and times that the event was last updated.
            (dict) --A range of dates and times that is used by the EventFilter and EntityFilter objects. If from is set and to is set: match items where the timestamp (startTime , endTime , or lastUpdatedTime ) is between from and to inclusive. If from is set and to is not set: match items where the timestamp value is equal to or after from . If from is not set and to is set: match items where the timestamp value is equal to or before to .
            from (datetime) --The starting date and time of a time range.
            to (datetime) --The ending date and time of a time range.
            
            entityArns (list) --A list of entity ARNs (unique identifiers).
            (string) --
            entityValues (list) --A list of entity identifiers, such as EC2 instance IDs (i-34ab692e ) or EBS volumes (vol-426ab23e ).
            (string) --
            eventTypeCategories (list) --A list of event type category codes (issue , scheduledChange , or accountNotification ).
            (string) --
            tags (list) --A map of entity tags attached to the affected entity.
            (dict) --
            (string) --
            (string) --
            
            eventStatusCodes (list) --A list of event status codes.
            (string) --
            

    :type nextToken: string
    :param nextToken: If the results of a search are large, only a portion of the results are returned, and a nextToken pagination token is returned in the response. To retrieve the next batch of results, reissue the search request and include the returned token. When all results have been returned, the response does not contain a pagination token value.

    :type maxResults: integer
    :param maxResults: The maximum number of items to return in one batch, between 10 and 100, inclusive.

    :type locale: string
    :param locale: The locale (language) to return information in. English (en) is the default and the only supported value at this time.

    :rtype: dict
    :return: {
        'events': [
            {
                'arn': 'string',
                'service': 'string',
                'eventTypeCode': 'string',
                'eventTypeCategory': 'issue'|'accountNotification'|'scheduledChange',
                'region': 'string',
                'availabilityZone': 'string',
                'startTime': datetime(2015, 1, 1),
                'endTime': datetime(2015, 1, 1),
                'lastUpdatedTime': datetime(2015, 1, 1),
                'statusCode': 'open'|'closed'|'upcoming'
            },
        ],
        'nextToken': 'string'
    }
    
    
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    Generate a presigned url given a client, its method, and arguments
    
    :type ClientMethod: string
    :param ClientMethod: The client method to presign for

    :type Params: dict
    :param Params: The parameters normally passed to
            ClientMethod.

    :type ExpiresIn: int
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)

    :type HttpMethod: string
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.

    """
    pass

def get_paginator(operation_name=None):
    """
    Create a paginator for an operation.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').

    :rtype: L{botocore.paginate.Paginator}
    """
    pass

def get_waiter():
    """
    
    """
    pass




'''

The MIT License (MIT)

Copyright (c) 2016 WavyCloud

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

'''

def add_attributes_to_findings(findingArns=None, attributes=None):
    """
    Assigns attributes (key and value pairs) to the findings that are specified by the ARNs of the findings.
    See also: AWS API Documentation
    
    Examples
    Assigns attributes (key and value pairs) to the findings that are specified by the ARNs of the findings.
    Expected Output:
    
    :example: response = client.add_attributes_to_findings(
        findingArns=[
            'string',
        ],
        attributes=[
            {
                'key': 'string',
                'value': 'string'
            },
        ]
    )
    
    
    :type findingArns: list
    :param findingArns: [REQUIRED]
            The ARNs that specify the findings that you want to assign attributes to.
            (string) --
            

    :type attributes: list
    :param attributes: [REQUIRED]
            The array of attributes that you want to assign to specified findings.
            (dict) --This data type is used as a request parameter in the AddAttributesToFindings and CreateAssessmentTemplate actions.
            key (string) -- [REQUIRED]The attribute key.
            value (string) --The value assigned to the attribute key.
            
            

    :rtype: dict
    :return: {
        'failedItems': {
            'string': {
                'failureCode': 'INVALID_ARN'|'DUPLICATE_ARN'|'ITEM_DOES_NOT_EXIST'|'ACCESS_DENIED'|'LIMIT_EXCEEDED'|'INTERNAL_ERROR',
                'retryable': True|False
            }
        }
    }
    
    
    """
    pass

def can_paginate(operation_name=None):
    """
    Check if an operation can be paginated.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').

    """
    pass

def create_assessment_target(assessmentTargetName=None, resourceGroupArn=None):
    """
    Creates a new assessment target using the ARN of the resource group that is generated by  CreateResourceGroup . You can create up to 50 assessment targets per AWS account. You can run up to 500 concurrent agents per AWS account. For more information, see Amazon Inspector Assessment Targets .
    See also: AWS API Documentation
    
    Examples
    Creates a new assessment target using the ARN of the resource group that is generated by CreateResourceGroup. You can create up to 50 assessment targets per AWS account. You can run up to 500 concurrent agents per AWS account.
    Expected Output:
    
    :example: response = client.create_assessment_target(
        assessmentTargetName='string',
        resourceGroupArn='string'
    )
    
    
    :type assessmentTargetName: string
    :param assessmentTargetName: [REQUIRED]
            The user-defined name that identifies the assessment target that you want to create. The name must be unique within the AWS account.
            

    :type resourceGroupArn: string
    :param resourceGroupArn: [REQUIRED]
            The ARN that specifies the resource group that is used to create the assessment target.
            

    :rtype: dict
    :return: {
        'assessmentTargetArn': 'string'
    }
    
    
    """
    pass

def create_assessment_template(assessmentTargetArn=None, assessmentTemplateName=None, durationInSeconds=None, rulesPackageArns=None, userAttributesForFindings=None):
    """
    Creates an assessment template for the assessment target that is specified by the ARN of the assessment target.
    See also: AWS API Documentation
    
    Examples
    Creates an assessment template for the assessment target that is specified by the ARN of the assessment target.
    Expected Output:
    
    :example: response = client.create_assessment_template(
        assessmentTargetArn='string',
        assessmentTemplateName='string',
        durationInSeconds=123,
        rulesPackageArns=[
            'string',
        ],
        userAttributesForFindings=[
            {
                'key': 'string',
                'value': 'string'
            },
        ]
    )
    
    
    :type assessmentTargetArn: string
    :param assessmentTargetArn: [REQUIRED]
            The ARN that specifies the assessment target for which you want to create the assessment template.
            

    :type assessmentTemplateName: string
    :param assessmentTemplateName: [REQUIRED]
            The user-defined name that identifies the assessment template that you want to create. You can create several assessment templates for an assessment target. The names of the assessment templates that correspond to a particular assessment target must be unique.
            

    :type durationInSeconds: integer
    :param durationInSeconds: [REQUIRED]
            The duration of the assessment run in seconds. The default value is 3600 seconds (one hour).
            

    :type rulesPackageArns: list
    :param rulesPackageArns: [REQUIRED]
            The ARNs that specify the rules packages that you want to attach to the assessment template.
            (string) --
            

    :type userAttributesForFindings: list
    :param userAttributesForFindings: The user-defined attributes that are assigned to every finding that is generated by the assessment run that uses this assessment template.
            (dict) --This data type is used as a request parameter in the AddAttributesToFindings and CreateAssessmentTemplate actions.
            key (string) -- [REQUIRED]The attribute key.
            value (string) --The value assigned to the attribute key.
            
            

    :rtype: dict
    :return: {
        'assessmentTemplateArn': 'string'
    }
    
    
    """
    pass

def create_resource_group(resourceGroupTags=None):
    """
    Creates a resource group using the specified set of tags (key and value pairs) that are used to select the EC2 instances to be included in an Amazon Inspector assessment target. The created resource group is then used to create an Amazon Inspector assessment target. For more information, see  CreateAssessmentTarget .
    See also: AWS API Documentation
    
    Examples
    Creates a resource group using the specified set of tags (key and value pairs) that are used to select the EC2 instances to be included in an Amazon Inspector assessment target. The created resource group is then used to create an Amazon Inspector assessment target.
    Expected Output:
    
    :example: response = client.create_resource_group(
        resourceGroupTags=[
            {
                'key': 'string',
                'value': 'string'
            },
        ]
    )
    
    
    :type resourceGroupTags: list
    :param resourceGroupTags: [REQUIRED]
            A collection of keys and an array of possible values, '[{'key':'key1','values':['Value1','Value2']},{'key':'Key2','values':['Value3']}]'.
            For example,'[{'key':'Name','values':['TestEC2Instance']}]'.
            (dict) --This data type is used as one of the elements of the ResourceGroup data type.
            key (string) -- [REQUIRED]A tag key.
            value (string) --The value assigned to a tag key.
            
            

    :rtype: dict
    :return: {
        'resourceGroupArn': 'string'
    }
    
    
    """
    pass

def delete_assessment_run(assessmentRunArn=None):
    """
    Deletes the assessment run that is specified by the ARN of the assessment run.
    See also: AWS API Documentation
    
    Examples
    Deletes the assessment run that is specified by the ARN of the assessment run.
    Expected Output:
    
    :example: response = client.delete_assessment_run(
        assessmentRunArn='string'
    )
    
    
    :type assessmentRunArn: string
    :param assessmentRunArn: [REQUIRED]
            The ARN that specifies the assessment run that you want to delete.
            

    :return: response = client.delete_assessment_run(
        assessmentRunArn='arn:aws:inspector:us-west-2:123456789012:target/0-nvgVhaxX/template/0-it5r2S4T/run/0-11LMTAVe',
    )
    
    print(response)
    
    
    """
    pass

def delete_assessment_target(assessmentTargetArn=None):
    """
    Deletes the assessment target that is specified by the ARN of the assessment target.
    See also: AWS API Documentation
    
    Examples
    Deletes the assessment target that is specified by the ARN of the assessment target.
    Expected Output:
    
    :example: response = client.delete_assessment_target(
        assessmentTargetArn='string'
    )
    
    
    :type assessmentTargetArn: string
    :param assessmentTargetArn: [REQUIRED]
            The ARN that specifies the assessment target that you want to delete.
            

    :return: response = client.delete_assessment_target(
        assessmentTargetArn='arn:aws:inspector:us-west-2:123456789012:target/0-0kFIPusq',
    )
    
    print(response)
    
    
    """
    pass

def delete_assessment_template(assessmentTemplateArn=None):
    """
    Deletes the assessment template that is specified by the ARN of the assessment template.
    See also: AWS API Documentation
    
    Examples
    Deletes the assessment template that is specified by the ARN of the assessment template.
    Expected Output:
    
    :example: response = client.delete_assessment_template(
        assessmentTemplateArn='string'
    )
    
    
    :type assessmentTemplateArn: string
    :param assessmentTemplateArn: [REQUIRED]
            The ARN that specifies the assessment template that you want to delete.
            

    :return: response = client.delete_assessment_template(
        assessmentTemplateArn='arn:aws:inspector:us-west-2:123456789012:target/0-nvgVhaxX/template/0-it5r2S4T',
    )
    
    print(response)
    
    
    """
    pass

def describe_assessment_runs(assessmentRunArns=None):
    """
    Describes the assessment runs that are specified by the ARNs of the assessment runs.
    See also: AWS API Documentation
    
    Examples
    Describes the assessment runs that are specified by the ARNs of the assessment runs.
    Expected Output:
    
    :example: response = client.describe_assessment_runs(
        assessmentRunArns=[
            'string',
        ]
    )
    
    
    :type assessmentRunArns: list
    :param assessmentRunArns: [REQUIRED]
            The ARN that specifies the assessment run that you want to describe.
            (string) --
            

    :rtype: dict
    :return: {
        'assessmentRuns': [
            {
                'arn': 'string',
                'name': 'string',
                'assessmentTemplateArn': 'string',
                'state': 'CREATED'|'START_DATA_COLLECTION_PENDING'|'START_DATA_COLLECTION_IN_PROGRESS'|'COLLECTING_DATA'|'STOP_DATA_COLLECTION_PENDING'|'DATA_COLLECTED'|'START_EVALUATING_RULES_PENDING'|'EVALUATING_RULES'|'FAILED'|'ERROR'|'COMPLETED'|'COMPLETED_WITH_ERRORS',
                'durationInSeconds': 123,
                'rulesPackageArns': [
                    'string',
                ],
                'userAttributesForFindings': [
                    {
                        'key': 'string',
                        'value': 'string'
                    },
                ],
                'createdAt': datetime(2015, 1, 1),
                'startedAt': datetime(2015, 1, 1),
                'completedAt': datetime(2015, 1, 1),
                'stateChangedAt': datetime(2015, 1, 1),
                'dataCollected': True|False,
                'stateChanges': [
                    {
                        'stateChangedAt': datetime(2015, 1, 1),
                        'state': 'CREATED'|'START_DATA_COLLECTION_PENDING'|'START_DATA_COLLECTION_IN_PROGRESS'|'COLLECTING_DATA'|'STOP_DATA_COLLECTION_PENDING'|'DATA_COLLECTED'|'START_EVALUATING_RULES_PENDING'|'EVALUATING_RULES'|'FAILED'|'ERROR'|'COMPLETED'|'COMPLETED_WITH_ERRORS'
                    },
                ],
                'notifications': [
                    {
                        'date': datetime(2015, 1, 1),
                        'event': 'ASSESSMENT_RUN_STARTED'|'ASSESSMENT_RUN_COMPLETED'|'ASSESSMENT_RUN_STATE_CHANGED'|'FINDING_REPORTED'|'OTHER',
                        'message': 'string',
                        'error': True|False,
                        'snsTopicArn': 'string',
                        'snsPublishStatusCode': 'SUCCESS'|'TOPIC_DOES_NOT_EXIST'|'ACCESS_DENIED'|'INTERNAL_ERROR'
                    },
                ],
                'findingCounts': {
                    'string': 123
                }
            },
        ],
        'failedItems': {
            'string': {
                'failureCode': 'INVALID_ARN'|'DUPLICATE_ARN'|'ITEM_DOES_NOT_EXIST'|'ACCESS_DENIED'|'LIMIT_EXCEEDED'|'INTERNAL_ERROR',
                'retryable': True|False
            }
        }
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def describe_assessment_targets(assessmentTargetArns=None):
    """
    Describes the assessment targets that are specified by the ARNs of the assessment targets.
    See also: AWS API Documentation
    
    Examples
    Describes the assessment targets that are specified by the ARNs of the assessment targets.
    Expected Output:
    
    :example: response = client.describe_assessment_targets(
        assessmentTargetArns=[
            'string',
        ]
    )
    
    
    :type assessmentTargetArns: list
    :param assessmentTargetArns: [REQUIRED]
            The ARNs that specifies the assessment targets that you want to describe.
            (string) --
            

    :rtype: dict
    :return: {
        'assessmentTargets': [
            {
                'arn': 'string',
                'name': 'string',
                'resourceGroupArn': 'string',
                'createdAt': datetime(2015, 1, 1),
                'updatedAt': datetime(2015, 1, 1)
            },
        ],
        'failedItems': {
            'string': {
                'failureCode': 'INVALID_ARN'|'DUPLICATE_ARN'|'ITEM_DOES_NOT_EXIST'|'ACCESS_DENIED'|'LIMIT_EXCEEDED'|'INTERNAL_ERROR',
                'retryable': True|False
            }
        }
    }
    
    
    """
    pass

def describe_assessment_templates(assessmentTemplateArns=None):
    """
    Describes the assessment templates that are specified by the ARNs of the assessment templates.
    See also: AWS API Documentation
    
    Examples
    Describes the assessment templates that are specified by the ARNs of the assessment templates.
    Expected Output:
    
    :example: response = client.describe_assessment_templates(
        assessmentTemplateArns=[
            'string',
        ]
    )
    
    
    :type assessmentTemplateArns: list
    :param assessmentTemplateArns: [REQUIRED]
            (string) --
            

    :rtype: dict
    :return: {
        'assessmentTemplates': [
            {
                'arn': 'string',
                'name': 'string',
                'assessmentTargetArn': 'string',
                'durationInSeconds': 123,
                'rulesPackageArns': [
                    'string',
                ],
                'userAttributesForFindings': [
                    {
                        'key': 'string',
                        'value': 'string'
                    },
                ],
                'createdAt': datetime(2015, 1, 1)
            },
        ],
        'failedItems': {
            'string': {
                'failureCode': 'INVALID_ARN'|'DUPLICATE_ARN'|'ITEM_DOES_NOT_EXIST'|'ACCESS_DENIED'|'LIMIT_EXCEEDED'|'INTERNAL_ERROR',
                'retryable': True|False
            }
        }
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def describe_cross_account_access_role():
    """
    Describes the IAM role that enables Amazon Inspector to access your AWS account.
    See also: AWS API Documentation
    
    Examples
    Describes the IAM role that enables Amazon Inspector to access your AWS account.
    Expected Output:
    
    :example: response = client.describe_cross_account_access_role()
    
    
    :rtype: dict
    :return: {
        'roleArn': 'string',
        'valid': True|False,
        'registeredAt': datetime(2015, 1, 1)
    }
    
    
    """
    pass

def describe_findings(findingArns=None, locale=None):
    """
    Describes the findings that are specified by the ARNs of the findings.
    See also: AWS API Documentation
    
    Examples
    Describes the findings that are specified by the ARNs of the findings.
    Expected Output:
    
    :example: response = client.describe_findings(
        findingArns=[
            'string',
        ],
        locale='EN_US'
    )
    
    
    :type findingArns: list
    :param findingArns: [REQUIRED]
            The ARN that specifies the finding that you want to describe.
            (string) --
            

    :type locale: string
    :param locale: The locale into which you want to translate a finding description, recommendation, and the short description that identifies the finding.

    :rtype: dict
    :return: {
        'findings': [
            {
                'arn': 'string',
                'schemaVersion': 123,
                'service': 'string',
                'serviceAttributes': {
                    'schemaVersion': 123,
                    'assessmentRunArn': 'string',
                    'rulesPackageArn': 'string'
                },
                'assetType': 'ec2-instance',
                'assetAttributes': {
                    'schemaVersion': 123,
                    'agentId': 'string',
                    'autoScalingGroup': 'string',
                    'amiId': 'string',
                    'hostname': 'string',
                    'ipv4Addresses': [
                        'string',
                    ]
                },
                'id': 'string',
                'title': 'string',
                'description': 'string',
                'recommendation': 'string',
                'severity': 'Low'|'Medium'|'High'|'Informational'|'Undefined',
                'numericSeverity': 123.0,
                'confidence': 123,
                'indicatorOfCompromise': True|False,
                'attributes': [
                    {
                        'key': 'string',
                        'value': 'string'
                    },
                ],
                'userAttributes': [
                    {
                        'key': 'string',
                        'value': 'string'
                    },
                ],
                'createdAt': datetime(2015, 1, 1),
                'updatedAt': datetime(2015, 1, 1)
            },
        ],
        'failedItems': {
            'string': {
                'failureCode': 'INVALID_ARN'|'DUPLICATE_ARN'|'ITEM_DOES_NOT_EXIST'|'ACCESS_DENIED'|'LIMIT_EXCEEDED'|'INTERNAL_ERROR',
                'retryable': True|False
            }
        }
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def describe_resource_groups(resourceGroupArns=None):
    """
    Describes the resource groups that are specified by the ARNs of the resource groups.
    See also: AWS API Documentation
    
    Examples
    Describes the resource groups that are specified by the ARNs of the resource groups.
    Expected Output:
    
    :example: response = client.describe_resource_groups(
        resourceGroupArns=[
            'string',
        ]
    )
    
    
    :type resourceGroupArns: list
    :param resourceGroupArns: [REQUIRED]
            The ARN that specifies the resource group that you want to describe.
            (string) --
            

    :rtype: dict
    :return: {
        'resourceGroups': [
            {
                'arn': 'string',
                'tags': [
                    {
                        'key': 'string',
                        'value': 'string'
                    },
                ],
                'createdAt': datetime(2015, 1, 1)
            },
        ],
        'failedItems': {
            'string': {
                'failureCode': 'INVALID_ARN'|'DUPLICATE_ARN'|'ITEM_DOES_NOT_EXIST'|'ACCESS_DENIED'|'LIMIT_EXCEEDED'|'INTERNAL_ERROR',
                'retryable': True|False
            }
        }
    }
    
    
    """
    pass

def describe_rules_packages(rulesPackageArns=None, locale=None):
    """
    Describes the rules packages that are specified by the ARNs of the rules packages.
    See also: AWS API Documentation
    
    Examples
    Describes the rules packages that are specified by the ARNs of the rules packages.
    Expected Output:
    
    :example: response = client.describe_rules_packages(
        rulesPackageArns=[
            'string',
        ],
        locale='EN_US'
    )
    
    
    :type rulesPackageArns: list
    :param rulesPackageArns: [REQUIRED]
            The ARN that specifies the rules package that you want to describe.
            (string) --
            

    :type locale: string
    :param locale: The locale that you want to translate a rules package description into.

    :rtype: dict
    :return: {
        'rulesPackages': [
            {
                'arn': 'string',
                'name': 'string',
                'version': 'string',
                'provider': 'string',
                'description': 'string'
            },
        ],
        'failedItems': {
            'string': {
                'failureCode': 'INVALID_ARN'|'DUPLICATE_ARN'|'ITEM_DOES_NOT_EXIST'|'ACCESS_DENIED'|'LIMIT_EXCEEDED'|'INTERNAL_ERROR',
                'retryable': True|False
            }
        }
    }
    
    
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    Generate a presigned url given a client, its method, and arguments
    
    :type ClientMethod: string
    :param ClientMethod: The client method to presign for

    :type Params: dict
    :param Params: The parameters normally passed to
            ClientMethod.

    :type ExpiresIn: int
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)

    :type HttpMethod: string
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.

    """
    pass

def get_assessment_report(assessmentRunArn=None, reportFileFormat=None, reportType=None):
    """
    Produces an assessment report that includes detailed and comprehensive results of a specified assessment run.
    See also: AWS API Documentation
    
    
    :example: response = client.get_assessment_report(
        assessmentRunArn='string',
        reportFileFormat='HTML'|'PDF',
        reportType='FINDING'|'FULL'
    )
    
    
    :type assessmentRunArn: string
    :param assessmentRunArn: [REQUIRED]
            The ARN that specifies the assessment run for which you want to generate a report.
            

    :type reportFileFormat: string
    :param reportFileFormat: [REQUIRED]
            Specifies the file format (html or pdf) of the assessment report that you want to generate.
            

    :type reportType: string
    :param reportType: [REQUIRED]
            Specifies the type of the assessment report that you want to generate. There are two types of assessment reports: a finding report and a full report. For more information, see Assessment Reports .
            

    :rtype: dict
    :return: {
        'status': 'WORK_IN_PROGRESS'|'FAILED'|'COMPLETED',
        'url': 'string'
    }
    
    
    """
    pass

def get_paginator(operation_name=None):
    """
    Create a paginator for an operation.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').

    :rtype: L{botocore.paginate.Paginator}
    """
    pass

def get_telemetry_metadata(assessmentRunArn=None):
    """
    Information about the data that is collected for the specified assessment run.
    See also: AWS API Documentation
    
    Examples
    Information about the data that is collected for the specified assessment run.
    Expected Output:
    
    :example: response = client.get_telemetry_metadata(
        assessmentRunArn='string'
    )
    
    
    :type assessmentRunArn: string
    :param assessmentRunArn: [REQUIRED]
            The ARN that specifies the assessment run that has the telemetry data that you want to obtain.
            

    :rtype: dict
    :return: {
        'telemetryMetadata': [
            {
                'messageType': 'string',
                'count': 123,
                'dataSize': 123
            },
        ]
    }
    
    
    """
    pass

def get_waiter():
    """
    
    """
    pass

def list_assessment_run_agents(assessmentRunArn=None, filter=None, nextToken=None, maxResults=None):
    """
    Lists the agents of the assessment runs that are specified by the ARNs of the assessment runs.
    See also: AWS API Documentation
    
    Examples
    Lists the agents of the assessment runs that are specified by the ARNs of the assessment runs.
    Expected Output:
    
    :example: response = client.list_assessment_run_agents(
        assessmentRunArn='string',
        filter={
            'agentHealths': [
                'HEALTHY'|'UNHEALTHY',
            ],
            'agentHealthCodes': [
                'IDLE'|'RUNNING'|'SHUTDOWN'|'UNHEALTHY'|'THROTTLED'|'UNKNOWN',
            ]
        },
        nextToken='string',
        maxResults=123
    )
    
    
    :type assessmentRunArn: string
    :param assessmentRunArn: [REQUIRED]
            The ARN that specifies the assessment run whose agents you want to list.
            

    :type filter: dict
    :param filter: You can use this parameter to specify a subset of data to be included in the action's response.
            For a record to match a filter, all specified filter attributes must match. When multiple values are specified for a filter attribute, any of the values can match.
            agentHealths (list) -- [REQUIRED]The current health state of the agent. Values can be set to HEALTHY or UNHEALTHY .
            (string) --
            agentHealthCodes (list) -- [REQUIRED]The detailed health state of the agent. Values can be set to IDLE , RUNNING , SHUTDOWN , UNHEALTHY , THROTTLED , and UNKNOWN .
            (string) --
            

    :type nextToken: string
    :param nextToken: You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the ListAssessmentRunAgents action. Subsequent calls to the action fill nextToken in the request with the value of NextToken from the previous response to continue listing data.

    :type maxResults: integer
    :param maxResults: You can use this parameter to indicate the maximum number of items that you want in the response. The default value is 10. The maximum value is 500.

    :rtype: dict
    :return: {
        'assessmentRunAgents': [
            {
                'agentId': 'string',
                'assessmentRunArn': 'string',
                'agentHealth': 'HEALTHY'|'UNHEALTHY',
                'agentHealthCode': 'IDLE'|'RUNNING'|'SHUTDOWN'|'UNHEALTHY'|'THROTTLED'|'UNKNOWN',
                'agentHealthDetails': 'string',
                'autoScalingGroup': 'string',
                'telemetryMetadata': [
                    {
                        'messageType': 'string',
                        'count': 123,
                        'dataSize': 123
                    },
                ]
            },
        ],
        'nextToken': 'string'
    }
    
    
    """
    pass

def list_assessment_runs(assessmentTemplateArns=None, filter=None, nextToken=None, maxResults=None):
    """
    Lists the assessment runs that correspond to the assessment templates that are specified by the ARNs of the assessment templates.
    See also: AWS API Documentation
    
    Examples
    Lists the assessment runs that correspond to the assessment templates that are specified by the ARNs of the assessment templates.
    Expected Output:
    
    :example: response = client.list_assessment_runs(
        assessmentTemplateArns=[
            'string',
        ],
        filter={
            'namePattern': 'string',
            'states': [
                'CREATED'|'START_DATA_COLLECTION_PENDING'|'START_DATA_COLLECTION_IN_PROGRESS'|'COLLECTING_DATA'|'STOP_DATA_COLLECTION_PENDING'|'DATA_COLLECTED'|'START_EVALUATING_RULES_PENDING'|'EVALUATING_RULES'|'FAILED'|'ERROR'|'COMPLETED'|'COMPLETED_WITH_ERRORS',
            ],
            'durationRange': {
                'minSeconds': 123,
                'maxSeconds': 123
            },
            'rulesPackageArns': [
                'string',
            ],
            'startTimeRange': {
                'beginDate': datetime(2015, 1, 1),
                'endDate': datetime(2015, 1, 1)
            },
            'completionTimeRange': {
                'beginDate': datetime(2015, 1, 1),
                'endDate': datetime(2015, 1, 1)
            },
            'stateChangeTimeRange': {
                'beginDate': datetime(2015, 1, 1),
                'endDate': datetime(2015, 1, 1)
            }
        },
        nextToken='string',
        maxResults=123
    )
    
    
    :type assessmentTemplateArns: list
    :param assessmentTemplateArns: The ARNs that specify the assessment templates whose assessment runs you want to list.
            (string) --
            

    :type filter: dict
    :param filter: You can use this parameter to specify a subset of data to be included in the action's response.
            For a record to match a filter, all specified filter attributes must match. When multiple values are specified for a filter attribute, any of the values can match.
            namePattern (string) --For a record to match a filter, an explicit value or a string containing a wildcard that is specified for this data type property must match the value of the assessmentRunName property of the AssessmentRun data type.
            states (list) --For a record to match a filter, one of the values specified for this data type property must be the exact match of the value of the assessmentRunState property of the AssessmentRun data type.
            (string) --
            durationRange (dict) --For a record to match a filter, the value that is specified for this data type property must inclusively match any value between the specified minimum and maximum values of the durationInSeconds property of the AssessmentRun data type.
            minSeconds (integer) --The minimum value of the duration range. Must be greater than zero.
            maxSeconds (integer) --The maximum value of the duration range. Must be less than or equal to 604800 seconds (1 week).
            rulesPackageArns (list) --For a record to match a filter, the value that is specified for this data type property must be contained in the list of values of the rulesPackages property of the AssessmentRun data type.
            (string) --
            startTimeRange (dict) --For a record to match a filter, the value that is specified for this data type property must inclusively match any value between the specified minimum and maximum values of the startTime property of the AssessmentRun data type.
            beginDate (datetime) --The minimum value of the timestamp range.
            endDate (datetime) --The maximum value of the timestamp range.
            completionTimeRange (dict) --For a record to match a filter, the value that is specified for this data type property must inclusively match any value between the specified minimum and maximum values of the completedAt property of the AssessmentRun data type.
            beginDate (datetime) --The minimum value of the timestamp range.
            endDate (datetime) --The maximum value of the timestamp range.
            stateChangeTimeRange (dict) --For a record to match a filter, the value that is specified for this data type property must match the stateChangedAt property of the AssessmentRun data type.
            beginDate (datetime) --The minimum value of the timestamp range.
            endDate (datetime) --The maximum value of the timestamp range.
            
            

    :type nextToken: string
    :param nextToken: You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the ListAssessmentRuns action. Subsequent calls to the action fill nextToken in the request with the value of NextToken from the previous response to continue listing data.

    :type maxResults: integer
    :param maxResults: You can use this parameter to indicate the maximum number of items that you want in the response. The default value is 10. The maximum value is 500.

    :rtype: dict
    :return: {
        'assessmentRunArns': [
            'string',
        ],
        'nextToken': 'string'
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def list_assessment_targets(filter=None, nextToken=None, maxResults=None):
    """
    Lists the ARNs of the assessment targets within this AWS account. For more information about assessment targets, see Amazon Inspector Assessment Targets .
    See also: AWS API Documentation
    
    Examples
    Lists the ARNs of the assessment targets within this AWS account.
    Expected Output:
    
    :example: response = client.list_assessment_targets(
        filter={
            'assessmentTargetNamePattern': 'string'
        },
        nextToken='string',
        maxResults=123
    )
    
    
    :type filter: dict
    :param filter: You can use this parameter to specify a subset of data to be included in the action's response.
            For a record to match a filter, all specified filter attributes must match. When multiple values are specified for a filter attribute, any of the values can match.
            assessmentTargetNamePattern (string) --For a record to match a filter, an explicit value or a string that contains a wildcard that is specified for this data type property must match the value of the assessmentTargetName property of the AssessmentTarget data type.
            

    :type nextToken: string
    :param nextToken: You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the ListAssessmentTargets action. Subsequent calls to the action fill nextToken in the request with the value of NextToken from the previous response to continue listing data.

    :type maxResults: integer
    :param maxResults: You can use this parameter to indicate the maximum number of items you want in the response. The default value is 10. The maximum value is 500.

    :rtype: dict
    :return: {
        'assessmentTargetArns': [
            'string',
        ],
        'nextToken': 'string'
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def list_assessment_templates(assessmentTargetArns=None, filter=None, nextToken=None, maxResults=None):
    """
    Lists the assessment templates that correspond to the assessment targets that are specified by the ARNs of the assessment targets.
    See also: AWS API Documentation
    
    Examples
    Lists the assessment templates that correspond to the assessment targets that are specified by the ARNs of the assessment targets.
    Expected Output:
    
    :example: response = client.list_assessment_templates(
        assessmentTargetArns=[
            'string',
        ],
        filter={
            'namePattern': 'string',
            'durationRange': {
                'minSeconds': 123,
                'maxSeconds': 123
            },
            'rulesPackageArns': [
                'string',
            ]
        },
        nextToken='string',
        maxResults=123
    )
    
    
    :type assessmentTargetArns: list
    :param assessmentTargetArns: A list of ARNs that specifies the assessment targets whose assessment templates you want to list.
            (string) --
            

    :type filter: dict
    :param filter: You can use this parameter to specify a subset of data to be included in the action's response.
            For a record to match a filter, all specified filter attributes must match. When multiple values are specified for a filter attribute, any of the values can match.
            namePattern (string) --For a record to match a filter, an explicit value or a string that contains a wildcard that is specified for this data type property must match the value of the assessmentTemplateName property of the AssessmentTemplate data type.
            durationRange (dict) --For a record to match a filter, the value specified for this data type property must inclusively match any value between the specified minimum and maximum values of the durationInSeconds property of the AssessmentTemplate data type.
            minSeconds (integer) --The minimum value of the duration range. Must be greater than zero.
            maxSeconds (integer) --The maximum value of the duration range. Must be less than or equal to 604800 seconds (1 week).
            rulesPackageArns (list) --For a record to match a filter, the values that are specified for this data type property must be contained in the list of values of the rulesPackageArns property of the AssessmentTemplate data type.
            (string) --
            

    :type nextToken: string
    :param nextToken: You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the ListAssessmentTemplates action. Subsequent calls to the action fill nextToken in the request with the value of NextToken from the previous response to continue listing data.

    :type maxResults: integer
    :param maxResults: You can use this parameter to indicate the maximum number of items you want in the response. The default value is 10. The maximum value is 500.

    :rtype: dict
    :return: {
        'assessmentTemplateArns': [
            'string',
        ],
        'nextToken': 'string'
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def list_event_subscriptions(resourceArn=None, nextToken=None, maxResults=None):
    """
    Lists all the event subscriptions for the assessment template that is specified by the ARN of the assessment template. For more information, see  SubscribeToEvent and  UnsubscribeFromEvent .
    See also: AWS API Documentation
    
    Examples
    Lists all the event subscriptions for the assessment template that is specified by the ARN of the assessment template.
    Expected Output:
    
    :example: response = client.list_event_subscriptions(
        resourceArn='string',
        nextToken='string',
        maxResults=123
    )
    
    
    :type resourceArn: string
    :param resourceArn: The ARN of the assessment template for which you want to list the existing event subscriptions.

    :type nextToken: string
    :param nextToken: You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the ListEventSubscriptions action. Subsequent calls to the action fill nextToken in the request with the value of NextToken from the previous response to continue listing data.

    :type maxResults: integer
    :param maxResults: You can use this parameter to indicate the maximum number of items you want in the response. The default value is 10. The maximum value is 500.

    :rtype: dict
    :return: {
        'subscriptions': [
            {
                'resourceArn': 'string',
                'topicArn': 'string',
                'eventSubscriptions': [
                    {
                        'event': 'ASSESSMENT_RUN_STARTED'|'ASSESSMENT_RUN_COMPLETED'|'ASSESSMENT_RUN_STATE_CHANGED'|'FINDING_REPORTED'|'OTHER',
                        'subscribedAt': datetime(2015, 1, 1)
                    },
                ]
            },
        ],
        'nextToken': 'string'
    }
    
    
    """
    pass

def list_findings(assessmentRunArns=None, filter=None, nextToken=None, maxResults=None):
    """
    Lists findings that are generated by the assessment runs that are specified by the ARNs of the assessment runs.
    See also: AWS API Documentation
    
    Examples
    Lists findings that are generated by the assessment runs that are specified by the ARNs of the assessment runs.
    Expected Output:
    
    :example: response = client.list_findings(
        assessmentRunArns=[
            'string',
        ],
        filter={
            'agentIds': [
                'string',
            ],
            'autoScalingGroups': [
                'string',
            ],
            'ruleNames': [
                'string',
            ],
            'severities': [
                'Low'|'Medium'|'High'|'Informational'|'Undefined',
            ],
            'rulesPackageArns': [
                'string',
            ],
            'attributes': [
                {
                    'key': 'string',
                    'value': 'string'
                },
            ],
            'userAttributes': [
                {
                    'key': 'string',
                    'value': 'string'
                },
            ],
            'creationTimeRange': {
                'beginDate': datetime(2015, 1, 1),
                'endDate': datetime(2015, 1, 1)
            }
        },
        nextToken='string',
        maxResults=123
    )
    
    
    :type assessmentRunArns: list
    :param assessmentRunArns: The ARNs of the assessment runs that generate the findings that you want to list.
            (string) --
            

    :type filter: dict
    :param filter: You can use this parameter to specify a subset of data to be included in the action's response.
            For a record to match a filter, all specified filter attributes must match. When multiple values are specified for a filter attribute, any of the values can match.
            agentIds (list) --For a record to match a filter, one of the values that is specified for this data type property must be the exact match of the value of the agentId property of the Finding data type.
            (string) --
            autoScalingGroups (list) --For a record to match a filter, one of the values that is specified for this data type property must be the exact match of the value of the autoScalingGroup property of the Finding data type.
            (string) --
            ruleNames (list) --For a record to match a filter, one of the values that is specified for this data type property must be the exact match of the value of the ruleName property of the Finding data type.
            (string) --
            severities (list) --For a record to match a filter, one of the values that is specified for this data type property must be the exact match of the value of the severity property of the Finding data type.
            (string) --
            rulesPackageArns (list) --For a record to match a filter, one of the values that is specified for this data type property must be the exact match of the value of the rulesPackageArn property of the Finding data type.
            (string) --
            attributes (list) --For a record to match a filter, the list of values that are specified for this data type property must be contained in the list of values of the attributes property of the Finding data type.
            (dict) --This data type is used as a request parameter in the AddAttributesToFindings and CreateAssessmentTemplate actions.
            key (string) -- [REQUIRED]The attribute key.
            value (string) --The value assigned to the attribute key.
            
            userAttributes (list) --For a record to match a filter, the value that is specified for this data type property must be contained in the list of values of the userAttributes property of the Finding data type.
            (dict) --This data type is used as a request parameter in the AddAttributesToFindings and CreateAssessmentTemplate actions.
            key (string) -- [REQUIRED]The attribute key.
            value (string) --The value assigned to the attribute key.
            
            creationTimeRange (dict) --The time range during which the finding is generated.
            beginDate (datetime) --The minimum value of the timestamp range.
            endDate (datetime) --The maximum value of the timestamp range.
            
            

    :type nextToken: string
    :param nextToken: You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the ListFindings action. Subsequent calls to the action fill nextToken in the request with the value of NextToken from the previous response to continue listing data.

    :type maxResults: integer
    :param maxResults: You can use this parameter to indicate the maximum number of items you want in the response. The default value is 10. The maximum value is 500.

    :rtype: dict
    :return: {
        'findingArns': [
            'string',
        ],
        'nextToken': 'string'
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def list_rules_packages(nextToken=None, maxResults=None):
    """
    Lists all available Amazon Inspector rules packages.
    See also: AWS API Documentation
    
    Examples
    Lists all available Amazon Inspector rules packages.
    Expected Output:
    
    :example: response = client.list_rules_packages(
        nextToken='string',
        maxResults=123
    )
    
    
    :type nextToken: string
    :param nextToken: You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the ListRulesPackages action. Subsequent calls to the action fill nextToken in the request with the value of NextToken from the previous response to continue listing data.

    :type maxResults: integer
    :param maxResults: You can use this parameter to indicate the maximum number of items you want in the response. The default value is 10. The maximum value is 500.

    :rtype: dict
    :return: {
        'rulesPackageArns': [
            'string',
        ],
        'nextToken': 'string'
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def list_tags_for_resource(resourceArn=None):
    """
    Lists all tags associated with an assessment template.
    See also: AWS API Documentation
    
    Examples
    Lists all tags associated with an assessment template.
    Expected Output:
    
    :example: response = client.list_tags_for_resource(
        resourceArn='string'
    )
    
    
    :type resourceArn: string
    :param resourceArn: [REQUIRED]
            The ARN that specifies the assessment template whose tags you want to list.
            

    :rtype: dict
    :return: {
        'tags': [
            {
                'key': 'string',
                'value': 'string'
            },
        ]
    }
    
    
    """
    pass

def preview_agents(previewAgentsArn=None, nextToken=None, maxResults=None):
    """
    Previews the agents installed on the EC2 instances that are part of the specified assessment target.
    See also: AWS API Documentation
    
    Examples
    Previews the agents installed on the EC2 instances that are part of the specified assessment target.
    Expected Output:
    
    :example: response = client.preview_agents(
        previewAgentsArn='string',
        nextToken='string',
        maxResults=123
    )
    
    
    :type previewAgentsArn: string
    :param previewAgentsArn: [REQUIRED]
            The ARN of the assessment target whose agents you want to preview.
            

    :type nextToken: string
    :param nextToken: You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the PreviewAgents action. Subsequent calls to the action fill nextToken in the request with the value of NextToken from the previous response to continue listing data.

    :type maxResults: integer
    :param maxResults: You can use this parameter to indicate the maximum number of items you want in the response. The default value is 10. The maximum value is 500.

    :rtype: dict
    :return: {
        'agentPreviews': [
            {
                'agentId': 'string',
                'autoScalingGroup': 'string'
            },
        ],
        'nextToken': 'string'
    }
    
    
    """
    pass

def register_cross_account_access_role(roleArn=None):
    """
    Registers the IAM role that Amazon Inspector uses to list your EC2 instances at the start of the assessment run or when you call the  PreviewAgents action.
    See also: AWS API Documentation
    
    Examples
    Registers the IAM role that Amazon Inspector uses to list your EC2 instances at the start of the assessment run or when you call the PreviewAgents action.
    Expected Output:
    
    :example: response = client.register_cross_account_access_role(
        roleArn='string'
    )
    
    
    :type roleArn: string
    :param roleArn: [REQUIRED]
            The ARN of the IAM role that Amazon Inspector uses to list your EC2 instances during the assessment run or when you call the PreviewAgents action.
            

    :return: response = client.register_cross_account_access_role(
        roleArn='arn:aws:iam::123456789012:role/inspector',
    )
    
    print(response)
    
    
    """
    pass

def remove_attributes_from_findings(findingArns=None, attributeKeys=None):
    """
    Removes entire attributes (key and value pairs) from the findings that are specified by the ARNs of the findings where an attribute with the specified key exists.
    See also: AWS API Documentation
    
    Examples
    Removes entire attributes (key and value pairs) from the findings that are specified by the ARNs of the findings where an attribute with the specified key exists.
    Expected Output:
    
    :example: response = client.remove_attributes_from_findings(
        findingArns=[
            'string',
        ],
        attributeKeys=[
            'string',
        ]
    )
    
    
    :type findingArns: list
    :param findingArns: [REQUIRED]
            The ARNs that specify the findings that you want to remove attributes from.
            (string) --
            

    :type attributeKeys: list
    :param attributeKeys: [REQUIRED]
            The array of attribute keys that you want to remove from specified findings.
            (string) --
            

    :rtype: dict
    :return: {
        'failedItems': {
            'string': {
                'failureCode': 'INVALID_ARN'|'DUPLICATE_ARN'|'ITEM_DOES_NOT_EXIST'|'ACCESS_DENIED'|'LIMIT_EXCEEDED'|'INTERNAL_ERROR',
                'retryable': True|False
            }
        }
    }
    
    
    """
    pass

def set_tags_for_resource(resourceArn=None, tags=None):
    """
    Sets tags (key and value pairs) to the assessment template that is specified by the ARN of the assessment template.
    See also: AWS API Documentation
    
    Examples
    Sets tags (key and value pairs) to the assessment template that is specified by the ARN of the assessment template.
    Expected Output:
    
    :example: response = client.set_tags_for_resource(
        resourceArn='string',
        tags=[
            {
                'key': 'string',
                'value': 'string'
            },
        ]
    )
    
    
    :type resourceArn: string
    :param resourceArn: [REQUIRED]
            The ARN of the assessment template that you want to set tags to.
            

    :type tags: list
    :param tags: A collection of key and value pairs that you want to set to the assessment template.
            (dict) --A key and value pair. This data type is used as a request parameter in the SetTagsForResource action and a response element in the ListTagsForResource action.
            key (string) -- [REQUIRED]A tag key.
            value (string) --A value assigned to a tag key.
            
            

    :return: response = client.set_tags_for_resource(
        resourceArn='arn:aws:inspector:us-west-2:123456789012:target/0-nvgVhaxX/template/0-7sbz2Kz0',
        tags=[
            {
                'key': 'Example',
                'value': 'example',
            },
        ],
    )
    
    print(response)
    
    
    """
    pass

def start_assessment_run(assessmentTemplateArn=None, assessmentRunName=None):
    """
    Starts the assessment run specified by the ARN of the assessment template. For this API to function properly, you must not exceed the limit of running up to 500 concurrent agents per AWS account.
    See also: AWS API Documentation
    
    Examples
    Starts the assessment run specified by the ARN of the assessment template. For this API to function properly, you must not exceed the limit of running up to 500 concurrent agents per AWS account.
    Expected Output:
    
    :example: response = client.start_assessment_run(
        assessmentTemplateArn='string',
        assessmentRunName='string'
    )
    
    
    :type assessmentTemplateArn: string
    :param assessmentTemplateArn: [REQUIRED]
            The ARN of the assessment template of the assessment run that you want to start.
            

    :type assessmentRunName: string
    :param assessmentRunName: You can specify the name for the assessment run. The name must be unique for the assessment template whose ARN is used to start the assessment run.

    :rtype: dict
    :return: {
        'assessmentRunArn': 'string'
    }
    
    
    """
    pass

def stop_assessment_run(assessmentRunArn=None):
    """
    Stops the assessment run that is specified by the ARN of the assessment run.
    See also: AWS API Documentation
    
    Examples
    Stops the assessment run that is specified by the ARN of the assessment run.
    Expected Output:
    
    :example: response = client.stop_assessment_run(
        assessmentRunArn='string'
    )
    
    
    :type assessmentRunArn: string
    :param assessmentRunArn: [REQUIRED]
            The ARN of the assessment run that you want to stop.
            

    :return: response = client.stop_assessment_run(
        assessmentRunArn='arn:aws:inspector:us-west-2:123456789012:target/0-nvgVhaxX/template/0-it5r2S4T/run/0-11LMTAVe',
    )
    
    print(response)
    
    
    """
    pass

def subscribe_to_event(resourceArn=None, event=None, topicArn=None):
    """
    Enables the process of sending Amazon Simple Notification Service (SNS) notifications about a specified event to a specified SNS topic.
    See also: AWS API Documentation
    
    Examples
    Enables the process of sending Amazon Simple Notification Service (SNS) notifications about a specified event to a specified SNS topic.
    Expected Output:
    
    :example: response = client.subscribe_to_event(
        resourceArn='string',
        event='ASSESSMENT_RUN_STARTED'|'ASSESSMENT_RUN_COMPLETED'|'ASSESSMENT_RUN_STATE_CHANGED'|'FINDING_REPORTED'|'OTHER',
        topicArn='string'
    )
    
    
    :type resourceArn: string
    :param resourceArn: [REQUIRED]
            The ARN of the assessment template that is used during the event for which you want to receive SNS notifications.
            

    :type event: string
    :param event: [REQUIRED]
            The event for which you want to receive SNS notifications.
            

    :type topicArn: string
    :param topicArn: [REQUIRED]
            The ARN of the SNS topic to which the SNS notifications are sent.
            

    :return: response = client.subscribe_to_event(
        event='ASSESSMENT_RUN_COMPLETED',
        resourceArn='arn:aws:inspector:us-west-2:123456789012:target/0-nvgVhaxX/template/0-7sbz2Kz0',
        topicArn='arn:aws:sns:us-west-2:123456789012:exampletopic',
    )
    
    print(response)
    
    
    """
    pass

def unsubscribe_from_event(resourceArn=None, event=None, topicArn=None):
    """
    Disables the process of sending Amazon Simple Notification Service (SNS) notifications about a specified event to a specified SNS topic.
    See also: AWS API Documentation
    
    Examples
    Disables the process of sending Amazon Simple Notification Service (SNS) notifications about a specified event to a specified SNS topic.
    Expected Output:
    
    :example: response = client.unsubscribe_from_event(
        resourceArn='string',
        event='ASSESSMENT_RUN_STARTED'|'ASSESSMENT_RUN_COMPLETED'|'ASSESSMENT_RUN_STATE_CHANGED'|'FINDING_REPORTED'|'OTHER',
        topicArn='string'
    )
    
    
    :type resourceArn: string
    :param resourceArn: [REQUIRED]
            The ARN of the assessment template that is used during the event for which you want to stop receiving SNS notifications.
            

    :type event: string
    :param event: [REQUIRED]
            The event for which you want to stop receiving SNS notifications.
            

    :type topicArn: string
    :param topicArn: [REQUIRED]
            The ARN of the SNS topic to which SNS notifications are sent.
            

    :return: response = client.unsubscribe_from_event(
        event='ASSESSMENT_RUN_COMPLETED',
        resourceArn='arn:aws:inspector:us-west-2:123456789012:target/0-nvgVhaxX/template/0-7sbz2Kz0',
        topicArn='arn:aws:sns:us-west-2:123456789012:exampletopic',
    )
    
    print(response)
    
    
    """
    pass

def update_assessment_target(assessmentTargetArn=None, assessmentTargetName=None, resourceGroupArn=None):
    """
    Updates the assessment target that is specified by the ARN of the assessment target.
    See also: AWS API Documentation
    
    Examples
    Updates the assessment target that is specified by the ARN of the assessment target.
    Expected Output:
    
    :example: response = client.update_assessment_target(
        assessmentTargetArn='string',
        assessmentTargetName='string',
        resourceGroupArn='string'
    )
    
    
    :type assessmentTargetArn: string
    :param assessmentTargetArn: [REQUIRED]
            The ARN of the assessment target that you want to update.
            

    :type assessmentTargetName: string
    :param assessmentTargetName: [REQUIRED]
            The name of the assessment target that you want to update.
            

    :type resourceGroupArn: string
    :param resourceGroupArn: [REQUIRED]
            The ARN of the resource group that is used to specify the new resource group to associate with the assessment target.
            

    :return: response = client.update_assessment_target(
        assessmentTargetArn='arn:aws:inspector:us-west-2:123456789012:target/0-nvgVhaxX',
        assessmentTargetName='Example',
        resourceGroupArn='arn:aws:inspector:us-west-2:123456789012:resourcegroup/0-yNbgL5Pt',
    )
    
    print(response)
    
    
    """
    pass

